#
# spec file for package binutils
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define flavor sparc64%{nil}

%if "%{flavor}" != ""
%define cross 1
%define targetarch %(echo %flavor | sed -e 's/i.86/i586/;s/ppc/powerpc/')
%define TARGET %targetarch

# Spec parsing does not support execution of external command,
# that's why we use the if-else chain.
%if "%{flavor}" == "i386"
ExcludeArch:    %ix86
%else
%if "%{flavor}" == "arm"
ExcludeArch:    %arm
%else
ExcludeArch:    %{flavor}
%endif
%endif

%endif

%if "%{flavor}" == ""
Name:           binutils
%else
Name:           cross-%{flavor}-binutils
%endif

BuildRequires:  bc
BuildRequires:  bison
BuildRequires:  dejagnu
BuildRequires:  fdupes
BuildRequires:  flex
BuildRequires:  gcc-c++
# for the testsuite
%if 0%{suse_version} >= 1210
BuildRequires:  glibc-devel-static
%endif
%if 0%{suse_version} > 1220
BuildRequires:  makeinfo
%endif
%if 0%{suse_version} > 1110
BuildRequires:  zlib-devel-static
%else
BuildRequires:  zlib-devel
%endif
%if %{suse_version} > 1500
BuildRequires:  libzstd-devel
%endif
Version:        2.43
Release:        1.0.2.1.sr20240803

# disable libalternatives for now until it's changed to not
# introduce cmake/cunit-tests into the bootstrap cycle
%if 0 && 0%{?suse_version} > 1500
%bcond_without libalternatives
%else
%bcond_with libalternatives
%endif

%bcond_without bootstrap

#
# RUN_TESTS
%define run_tests %(test ! -f %_sourcedir/RUN_TESTS ; echo $?)
# check the vanilla binutils, with no patches applied
# TEST_VANILLA
%define test_vanilla %(test ! -f %_sourcedir/TEST_VANILLA ; echo $?)
#
# handle test suite failures
#
%ifarch alpha %arm aarch64 hppa mips sh4 %sparc
%define	make_check_handling	true
%else
# XXX check again
# XXX disabled because gold is seriously broken for now
# Note that some gold tests fail due to gcc-PIE which leads PIE executables
%define	make_check_handling	true
%endif
# let make check fail anyway if RUN_TESTS was requested
%if %{run_tests}
%define	make_check_handling	false
%endif
# handle all binary object formats supported by SUSE (and a few more)
%ifarch %ix86 %arm aarch64 ia64 ppc ppc64 ppc64le riscv64 s390 s390x x86_64 %x86_64
%define build_multitarget 1
%else
%define build_multitarget 0
%endif
%define target_list aarch64 alpha armv5l armv6l armv7l armv8l avr pru epiphany hppa hppa64 i686 ia64 m68k mips powerpc powerpc64 powerpc64le riscv64 rx s390 s390x sh4 sparc sparc64 x86_64 xtensa

%define build_gprofng 0

%if %{suse_version} > 1500
%ifarch aarch64 %ix86 x86_64 %x86_64
%define build_gprofng 1
%endif
%endif

#
#
#
URL:            https://www.gnu.org/software/binutils/
PreReq:         %{install_info_prereq}
# bug437293
%ifarch ppc64
Obsoletes:      binutils-64bit
%endif
#
Summary:        GNU Binutils
License:        GFDL-1.3-only AND GPL-3.0-or-later
Group:          Development/Tools/Building
Source:         binutils-%{version}.tar.bz2
Source2:        binutils-%{version}.tar.bz2.sig
Source3:        binutils.keyring
Source4:        baselibs.conf
Patch1:         binutils-2.43-branch.diff.gz
Patch3:         binutils-skip-rpaths.patch
Patch4:         s390-biarch.diff
Patch5:         x86-64-biarch.patch
Patch6:         unit-at-a-time.patch
Patch8:         ld-relro.diff
Patch9:         testsuite.diff
Patch10:        enable-targets-gold.diff
Patch12:        s390-pic-dso.diff
Patch14:        binutils-build-as-needed.diff
Patch15:        binutils-znow.patch
Patch22:        binutils-bfd_h.patch
Patch34:        aarch64-common-pagesize.patch
Patch37:        binutils-revert-plt32-in-branches.diff
Patch38:        binutils-fix-invalid-op-errata.diff
Patch39:        binutils-revert-nm-symversion.diff
Patch40:        binutils-fix-abierrormsg.diff
Patch41:        binutils-fix-relax.diff
Patch42:        binutils-compat-old-behaviour.diff
Patch43:        binutils-revert-hlasm-insns.diff
Patch44:        binutils-revert-rela.diff
Patch60:        binutils-disable-code-arch-error.diff
Patch90:        cross-avr-nesc-as.patch
Patch92:        cross-avr-omit_section_dynsym.patch
Patch93:        cross-avr-size.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if %{with libalternatives}
Requires:       alts
%else
PreReq:         update-alternatives
%endif

%description
C compiler utilities: ar, as, gprof, ld, nm, objcopy, objdump, ranlib,
size, strings, and strip. These utilities are needed whenever you want
to compile a program or kernel.

%package gold
Summary:        The gold linker
License:        GPL-3.0-or-later
Group:          Development/Tools/Building
Requires:       binutils = %{version}-%{release}
%if %{with libalternatives}
Requires:       alts
%else
PreReq:         update-alternatives
%endif
%if 0%{!?cross:1} && 0%{?suse_version} >= 1310
%define gold_archs %ix86 aarch64 %arm x86_64 %x86_64 ppc ppc64 ppc64le s390x %sparc
%endif

%description gold
gold is an ELF linker.	It is intended to have complete support for ELF
and to run as fast as possible on modern systems.  For normal use it is
a drop-in replacement for the older GNU linker.

%package devel
Summary:        GNU binutils (BFD development files)
License:        GPL-3.0-or-later
Group:          Development/Libraries/C and C++
Requires:       binutils = %{version}-%{release}
Requires:       zlib-devel
%if %{suse_version} > 1500
Requires:       libzstd-devel
%endif
Provides:       binutils:/usr/include/bfd.h

%description devel
This package includes header files and static libraries necessary to
build programs which use the GNU BFD library, which is part of
binutils.

%package -n libctf0
Summary:        Compact C Type Format library (runtime, BFD dependency)
License:        GFDL-1.3-only AND GPL-3.0-or-later
Group:          Development/Tools/Building

%description -n libctf0
This package includes the libctf shared library.
The Compact C Type Format (CTF) is a way of representing information about a binary program

%package -n libctf-nobfd0
Summary:        Compact C Type Format library (runtime, no BFD dependency)
License:        GFDL-1.3-only AND GPL-3.0-or-later
Group:          Development/Tools/Building

%description -n libctf-nobfd0
This package includes the libctf-nobfd shared library.
The Compact C Type Format (CTF) is a way of representing information about a binary program

%package -n gprofng
Summary:        The next generation profiling tool for Linux
License:        GFDL-1.3-only AND GPL-3.0-or-later
Group:          Development/Tools/Building

%description -n gprofng
The next generation profiling tool for Linux

%ifarch %arm
%define HOST %{_target_cpu}-suse-linux-gnueabi
%else
%define HOST %(echo %{_target_cpu} | sed -s -e "s/x86_64_v./x86_64/" -e "s/parisc/hppa/" -e "s/i.86/i586/" -e "s/ppc/powerpc/" -e "s/sparc64v.*/sparc64/" -e "s/sparcv.*/sparc/")-suse-linux
%endif
%define DIST %(echo '%distribution' | sed 's/ (.*)//')

%if 0%{suse_version} >= 1500
# Synchronize output by lines, useful for configure output
%define make_output_sync -Oline
%endif

%prep
echo "make check will return with %{make_check_handling} in case of testsuite failures."
%setup -q -n binutils-%{version}

# Backup flex and biscon files for later verification.
cp ld/ldlex.l ld/ldlex.l.orig
cp ld/ldgram.y ld/ldgram.y.orig

# Patch is outside test_vanilla because it's supposed to be the
# patch bringing the tarball to the newest upstream version
%patch -P 1 -p1
%if !%{test_vanilla}
%patch -P 3 -p1
%patch -P 4
%patch -P 5
%patch -P 6
%patch -P 8
%patch -P 9
%patch -P 10
%patch -P 12
%patch -P 14
%patch -P 15
%patch -P 22
%patch -P 34 -p1
%if %{suse_version} < 1550
%patch -P 37 -p1
%endif
%patch -P 38
%patch -P 39 -p1
%patch -P 40 -p1
%patch -P 41 -p1
%if %{suse_version} < 1550
%patch -P 42 -p1
%patch -P 43 -p1
%patch -P 44 -p1
%endif
%patch -P 60 -p1
%if "%{TARGET}" == "avr"
cp gas/config/tc-avr.h gas/config/tc-avr-nesc.h
%patch -P 90
%patch -P 92
%patch -P 93 -p1
%endif
#
# test_vanilla
%endif

# Due to legacy flex version present in SLE-12 (and older), we cannot
# re-generate flex and bison files and so we verify that any patch modify these files.
diff -u ld/ldlex.l ld/ldlex.l.orig
diff -u ld/ldgram.y ld/ldgram.y.orig

%build
%define _lto_cflags %{nil}
sed -i -e '/BFD_VERSION_DATE/s/$/-%(echo %release | sed 's/\.[0-9]*$//')/' bfd/version.h
RPM_OPT_FLAGS="$RPM_OPT_FLAGS -Wno-error"

%if 0%{!?cross:1}
# Building native binutils
echo "Building native binutils."
%if %build_multitarget
EXTRA_TARGETS="%(printf ,%%s-suse-linux %target_list)"
EXTRA_TARGETS="$EXTRA_TARGETS,powerpc-macos,powerpc-macos10,spu-elf,x86_64-pep,bpf-none"
%else
EXTRA_TARGETS=
%ifarch sparc
EXTRA_TARGETS="$EXTRA_TARGETS,sparc64-suse-linux"
%endif
%ifarch ppc
EXTRA_TARGETS="$EXTRA_TARGETS,powerpc64-suse-linux"
%endif
%ifarch s390
EXTRA_TARGETS="$EXTRA_TARGETS,s390x-suse-linux"
%endif
%ifarch s390x
EXTRA_TARGETS="$EXTRA_TARGETS,s390-suse-linux"
%endif
%ifarch %ix86
EXTRA_TARGETS="$EXTRA_TARGETS,x86_64-suse-linux"
%endif
%ifarch ppc ppc64 ppc64le
EXTRA_TARGETS="$EXTRA_TARGETS,spu-elf"
%endif
%ifarch %arm
EXTRA_TARGETS="$EXTRA_TARGETS,arm-suse-linux-gnueabi"
%endif
%ifarch aarch64
EXTRA_TARGETS="$EXTRA_TARGETS,aarch64-suse-linux"
%endif
%endif
# Normally we'd like to add --enable-deterministic-archives
# here (which by default makes uid/mtime be zero for archive
# members), to increase chances of getting a reproducable build
# But this breaks Makefile rules when directly accessing archives:
# rebuilding the same archive from unchanged .o files recreates
# it, because timestamps in the .a are 0, unequal to the actual timestamp
# of the .o files :-/
#
# Enable the following 2 configure options explicitly
# (--enable-warn-execstack=yes, --enable-warn-rwx-segments=yes)
# as they are not enabled by default for some targets (and we use --enable-targets=[many]).
%define common_flags CFLAGS="${RPM_OPT_FLAGS}" CXXFLAGS="${RPM_OPT_FLAGS}" \\\
	--prefix=%{_prefix} --libdir=%{_libdir} \\\
	--infodir=%{_infodir} --mandir=%{_mandir} \\\
	--with-bugurl=https://bugs.opensuse.org/ \\\
	--with-pkgversion="GNU Binutils; %{DIST}" \\\
	--with-separate-debug-dir=%{_prefix}/lib/debug \\\
	--with-pic --with-system-zlib --build=%{HOST}
mkdir build-dir
cd build-dir
../configure %common_flags \
	${EXTRA_TARGETS:+--enable-targets="${EXTRA_TARGETS#,}"} \
	--enable-plugins \
%ifarch %gold_archs
	--enable-gold \
	--enable-threads \
%endif
%if %{suse_version} <= 1320
	CXX="g++ -std=gnu++11" \
	--disable-x86-relax-relocations \
	--disable-compressed-debug-sections \
%endif
%if %{suse_version} > 1320
	--enable-compressed-debug-sections=gas \
%endif
%if %{suse_version} < 1550
	--disable-x86-used-note \
	--disable-separate-code \
%endif
	--enable-new-dtags \
%if "%{TARGET}" != "mips"
	--enable-default-hash-style=both \
%endif
	--enable-shared \
%if %{suse_version} > 1500
%if %{with bootstrap} && 0%{?do_profiling}
	--enable-pgo-build=lto \
%endif
	--enable-colored-disassembly \
%endif
%if ! %build_gprofng
	--disable-gprofng \
%endif
	--enable-obsolete \
	--enable-warn-execstack=yes \
	--enable-warn-rwx-segments=yes

#FIXME: enable in the future
#%if %{suse_version} > 1550
#  --enable-default-compressed-debug-sections-algorithm=zstd \
#%endif

# we patch headers (bfd-in.h) that are input to other headers
# which are generated only with --enable-maintainer-mode (which we
# don't do) or explicitely by make headers, so do this:
make %{?make_output_sync} %{?_smp_mflags} all-bfd TARGET-bfd=headers V=1
# the above interacts with --enable-pgo-build=lto because all-bfd doesn't
# have the PGO handling, hence it's config.cache files are wrong
# remove all of those for reconfigure
rm */config.cache
# force reconfiguring
rm bfd/Makefile
make %{?make_output_sync} %{?_smp_mflags} V=1

%else
# building cross-TARGET-binutils
echo "Building cross binutils."
mkdir build-dir
cd build-dir
EXTRA_TARGETS=
%if "%{TARGET}" == "sparc"
EXTRA_TARGETS="$EXTRA_TARGETS,sparc64-suse-linux"
%endif
%if "%{TARGET}" == "powerpc"
EXTRA_TARGETS="$EXTRA_TARGETS,powerpc64-suse-linux"
%endif
%if "%{TARGET}" == "s390"
EXTRA_TARGETS="$EXTRA_TARGETS,s390x-suse-linux"
%endif
%if "%{TARGET}" == "s390x"
EXTRA_TARGETS="$EXTRA_TARGETS,s390-suse-linux"
%endif
%if "%{TARGET}" == "i586"
EXTRA_TARGETS="$EXTRA_TARGETS,x86_64-suse-linux"
%endif
%if "%{TARGET}" == "hppa"
EXTRA_TARGETS="$EXTRA_TARGETS,hppa64-suse-linux"
%endif
%if "%{TARGET}" == "arm"
EXTRA_TARGETS="$EXTRA_TARGETS,arm-suse-linux-gnueabi"
%endif
%if "%{TARGET}" == "aarch64"
EXTRA_TARGETS="$EXTRA_TARGETS,aarch64-suse-linux"
%endif
%if "%{TARGET}" == "avr" || "%{TARGET}" == "spu" || "%{TARGET}" == "pru"
%define TARGET_OS %{TARGET}
%else
%if "%{TARGET}" == "epiphany" || "%{TARGET}" == "riscv32" || "%{TARGET}" == "rx"
%define TARGET_OS %{TARGET}-elf
%else
%if "%{TARGET}" == "arm"
%define TARGET_OS %{TARGET}-suse-linux-gnueabi
%else
%if "%{TARGET}" == "bpf"
%define TARGET_OS %{TARGET}-none
%else
%define TARGET_OS %{TARGET}-suse-linux
%endif
%endif
%endif
%endif
../configure CFLAGS="${RPM_OPT_FLAGS}" \
  --prefix=%{_prefix} \
  --with-bugurl=https://bugs.opensuse.org/ \
  --with-pkgversion="GNU Binutils; %{DIST}" \
  --with-system-zlib \
  --disable-nls \
  --enable-new-dtags \
	--enable-obsolete \
	--disable-gprofng \
%if %{suse_version} <= 1320
  --disable-x86-relax-relocations \
%endif
  --build=%{HOST} --target=%{TARGET_OS} \
%if "%{TARGET}" == "spu"
  --with-sysroot=/usr/spu \
%else
  --with-sysroot=%{_prefix}/%{TARGET_OS}/sys-root \
%endif
%if "%{TARGET}" != "mips"
  --enable-default-hash-style=both \
%endif
  ${EXTRA_TARGETS:+--enable-targets="${EXTRA_TARGETS#,}"}
make %{?make_output_sync} %{?_smp_mflags} all-bfd TARGET-bfd=headers V=1
rm */config.cache
# force reconfiguring
rm bfd/Makefile
make %{?make_output_sync} %{?_smp_mflags} V=1
%if "%{TARGET}" == "avr"
# build an extra nesC version because nesC requires $'s in identifiers
cp -a gas gas-nesc
echo '#include "tc-%{TARGET}-nesc.h"' > gas-nesc/targ-cpu.h
make -C gas-nesc clean
make -C gas-nesc %{?make_output_sync} %{?_smp_mflags}
%endif
%endif

%check
unset SUSE_ASNEEDED
# newer distros set this envvar (e.g. to get deterministic archives by default)
# but of course that breaks tests that precisely are
# designed for checking file replacement in archives based on mtime.
# just get rid of it for the binutils testsuite
unset SOURCE_DATE_EPOCH
cd build-dir
%if 0%{?cross:1}
make -k check CFLAGS="-O2 -g" CXXFLAGS="-O2 -g" CFLAGS_FOR_TARGET="-O2 -g" CXXFLAGS_FOR_TARGET="-O2 -g" || %{make_check_handling}
%else
# _FORTIFY_SOURCE does not work with -O0
make -k check CFLAGS="-g $RPM_OPT_FLAGS -U_FORTIFY_SOURCE" CXXFLAGS="-g $RPM_OPT_FLAGS -U_FORTIFY_SOURCE" CFLAGS_FOR_TARGET="-g $RPM_OPT_FLAGS -U_FORTIFY_SOURCE" CXXFLAGS_FOR_TARGET="-g $RPM_OPT_FLAGS -U_FORTIFY_SOURCE" || %{make_check_handling}
%endif

%install
cd build-dir
%if 0%{!?cross:1}
# installing native binutils
%ifarch %gold_archs
make DESTDIR=%{buildroot} install-gold
ln -sf ld.gold %{buildroot}%{_bindir}/gold
%endif
make DESTDIR=%{buildroot} install-info install
make DESTDIR=%{buildroot} install-bfd install-opcodes
if [ ! -f "%{buildroot}/%_bindir/ld.bfd" ]; then
  mv "%{buildroot}/%_bindir"/{ld,ld.bfd};
else
  rm -f "%{buildroot}/%_bindir/ld";
fi
%if ! 0%{with libalternatives}
mkdir -p "%{buildroot}/%_sysconfdir/alternatives";
# Keep older versions of brp-symlink happy
%if %{suse_version} < 1310
ln -s "%_bindir/ld" "%{buildroot}/%_sysconfdir/alternatives/ld"
%endif
ln -s "%_sysconfdir/alternatives/ld" "%{buildroot}/%_bindir/ld";
%else
ln -s %{_bindir}/alts "%{buildroot}/%_bindir/ld";
mkdir -p %{buildroot}%{_datadir}/libalternatives/ld;
cat > %{buildroot}%{_datadir}/libalternatives/ld/1.conf <<EOF
binary=%{_bindir}/ld.gold
EOF
cat > %{buildroot}%{_datadir}/libalternatives/ld/2.conf <<EOF
binary=%{_bindir}/ld.bfd
EOF
%endif

rm -rf %{buildroot}%{_prefix}/%{HOST}/bin
mkdir -p %{buildroot}%{_prefix}/%{HOST}/bin
ln -sf ../../bin/{ar,as,ld,nm,ranlib,strip} %{buildroot}%{_prefix}/%{HOST}/bin
mv %{buildroot}%{_prefix}/%{HOST}/lib/ldscripts $RPM_BUILD_ROOT%{_libdir}
rm -f $RPM_BUILD_ROOT%{_libdir}/ldscripts/stamp
ln -sf ../../%{_lib}/ldscripts %{buildroot}%{_prefix}/%{HOST}/lib/ldscripts
# Install header files
make -C libiberty install_to_libdir target_header_dir=/usr/include DESTDIR=%{buildroot}
# We want the PIC libiberty.a
install -m 644 libiberty/pic/libiberty.a %{buildroot}%{_libdir}
#
chmod a+x %{buildroot}%{_libdir}/libbfd-*
chmod a+x %{buildroot}%{_libdir}/libopcodes-*
# No shared linking outside binutils
rm %{buildroot}%{_libdir}/lib{bfd,opcodes}.so
rm %{buildroot}%{_libdir}/lib{bfd,opcodes,ctf,ctf-nobfd}.la
rm -f %{buildroot}%{_libdir}/gprofng/lib*.{l,}a
# Remove unwanted files to shut up rpm
rm -f %{buildroot}%{_infodir}/configure* $RPM_BUILD_ROOT%{_infodir}/standards.info*
rm -f %{buildroot}%{_mandir}/man1/dlltool.1 $RPM_BUILD_ROOT%{_mandir}/man1/windres.1 $RPM_BUILD_ROOT%{_mandir}/man1/windmc.1
cd ..
%find_lang binutils
%find_lang bfd binutils.lang
%find_lang gas binutils.lang
%find_lang ld binutils.lang
%find_lang opcodes binutils.lang
%find_lang gprof binutils.lang
%ifarch %gold_archs
%find_lang gold binutils-gold.lang
%endif
mkdir -p %{buildroot}%{_docdir}/%{name}
install -m 644 binutils/NEWS %{buildroot}%{_docdir}/%{name}/NEWS-binutils
install -m 644 gas/NEWS %{buildroot}%{_docdir}/%{name}/NEWS-gas
install -m 644 ld/NEWS %{buildroot}%{_docdir}/%{name}/NEWS-ld
%else
# installing cross-TARGET-binutils and TARGET-binutils
make DESTDIR=%{buildroot} install
# Replace hard links by symlinks, so that rpmlint doesn't complain
T=$(basename %{buildroot}/usr/%{TARGET_OS})
for f in %{buildroot}/usr/$T/bin/* ; do
   ln -sf /usr/bin/$T-$(basename $f) $f
done
%if "%{TARGET}" == "arm"
# Instead of building duplicate binutils, add symlinks
for f in %{buildroot}%{_bindir}/${T}-* ; do
  _toolname=${f##$(dirname $f)/${T}-}
  for p in arm-none-eabi; do
    ln -sf %{_bindir}/$T-${_toolname} %{buildroot}%{_bindir}/$p-${_toolname}
  done
done
%endif
%if "%{TARGET}" == "riscv64"
# Instead of building duplicate binutils, add symlinks
for f in %{buildroot}/usr/$T/bin/* ; do
  for p in riscv64-elf; do
    ln -sf %{_bindir}/$T-$(basename $f) %{buildroot}%{_bindir}/$p-$(basename $f)
  done
done
%endif
%if "%{TARGET}" == "avr"
install -c gas-nesc/as-new %{buildroot}%{_prefix}/bin/%{TARGET_OS}-nesc-as
ln -sf ../../bin/%{TARGET_OS}-nesc-as %{buildroot}%{_prefix}/%{TARGET_OS}/bin/nesc-as
%endif
rm -rf %{buildroot}%{_mandir}
rm -rf %{buildroot}%{_infodir}
rm -rf %{buildroot}%{_prefix}/lib*
rm -rf %{buildroot}%{_prefix}/include
rm -f %{buildroot}%{_prefix}/bin/*-c++filt
> ../binutils.lang
%endif
%fdupes %{buildroot}%{_prefix}

%if 0%{!?cross:1}
%post
/sbin/ldconfig
%if ! %{with libalternatives}
"%_sbindir/update-alternatives" --install \
	"%_bindir/ld" ld "%_bindir/ld.bfd" 2
%endif
%install_info --info-dir=%{_infodir} %{_infodir}/as.info.gz
%install_info --info-dir=%{_infodir} %{_infodir}/bfd.info.gz
%install_info --info-dir=%{_infodir} %{_infodir}/binutils.info.gz
%install_info --info-dir=%{_infodir} %{_infodir}/gprof.info.gz
%install_info --info-dir=%{_infodir} %{_infodir}/ld.info.gz

%if ! %{with libalternatives}
%post gold
"%_sbindir/update-alternatives" --install \
	"%_bindir/ld" ld "%_bindir/ld.gold" 1
%endif

%post -n libctf0 -p /sbin/ldconfig
%post -n libctf-nobfd0 -p /sbin/ldconfig

%if %{with libalternatives}
%pre
# removing old update-alternatives entries
if [ "$1" -gt 0 ] && [ -f %{_sbindir}/update-alternatives ] ; then
	"%_sbindir/update-alternatives" --remove ld "%_bindir/ld.bfd";
fi;

%pre gold
# removing old update-alternatives entries
if [ "$1" -gt 0 ] && [ -f %{_sbindir}/update-alternatives ] ; then
	"%_sbindir/update-alternatives" --remove ld "%_bindir/ld.gold";
fi;
%endif

%preun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/as.info.gz
%install_info_delete --info-dir=%{_infodir} %{_infodir}/bfd.info.gz
%install_info_delete --info-dir=%{_infodir} %{_infodir}/binutils.info.gz
%install_info_delete --info-dir=%{_infodir} %{_infodir}/gprof.info.gz
%install_info_delete --info-dir=%{_infodir} %{_infodir}/ld.info.gz
%if ! %{with libalternatives}
if [ "$1" = 0 ]; then
	"%_sbindir/update-alternatives" --remove ld "%_bindir/ld.bfd";
fi;
%endif

%if ! %{with libalternatives}
%preun gold
if [ "$1" = 0 ]; then
	"%_sbindir/update-alternatives" --remove ld "%_bindir/ld.gold";
fi;
%endif

%postun -n libctf0 -p /sbin/ldconfig
%postun -n libctf-nobfd0 -p /sbin/ldconfig

%postun -p /sbin/ldconfig
%endif

%files -f binutils.lang
%defattr(-,root,root)
%if 0%{!?cross:1}
%{_docdir}/%{name}
%{_prefix}/%{HOST}/bin/*
%{_prefix}/%{HOST}/lib/ldscripts
%{_libdir}/ldscripts
%{_libdir}/libsframe.so.*
%if %build_gprofng
%{_libdir}/libgprofng.so.*
%endif
%dir %{_libdir}/bfd-plugins
%{_libdir}/bfd-plugins/libdep.so
%{_bindir}/*
%if ! 0%{with libalternatives}
%ghost %_sysconfdir/alternatives/ld
%else
%dir %{_datadir}/libalternatives
%dir %{_datadir}/libalternatives/ld
%{_datadir}/libalternatives/ld/2.conf
%endif
%ifarch %gold_archs
%exclude %{_bindir}/gold
%exclude %{_bindir}/ld.gold
%endif
%doc %{_infodir}/*.gz
%{_libdir}/lib*-%{version}*.so
%doc %{_mandir}/man1/*.1.gz
%else
%{_prefix}/%{TARGET_OS}
%{_prefix}/bin/*
%endif

%ifarch %gold_archs
%files gold -f binutils-gold.lang
%defattr(-,root,root)
%doc gold/NEWS gold/README
%{_bindir}/gold
%{_bindir}/ld.gold
%if %{with libalternatives}
%dir %{_datadir}/libalternatives
%dir %{_datadir}/libalternatives/ld
%{_datadir}/libalternatives/ld/1.conf
%endif
%endif

%if 0%{!?cross:1}
%files devel
%defattr(-,root,root)
%{_prefix}/include/*.h
%{_libdir}/lib*.*a
%{_libdir}/libctf.so
%{_libdir}/libctf-nobfd.so
%{_libdir}/libsframe.so
%if %build_gprofng
%{_libdir}/libgprofng.so
%endif

%files -n libctf0
%defattr(-,root,root)
%{_libdir}/libctf.so.*

%files -n libctf-nobfd0
%defattr(-,root,root)
%{_libdir}/libctf-nobfd.so.*

%if %{suse_version} > 1500
%ifarch %ix86 x86_64 %x86_64 aarch64
%files -n gprofng
%defattr(-,root,root)
%dir %{_libdir}/gprofng/
%{_libdir}/gprofng/lib*.so
%{_distconfdir}/gprofng.rc
%endif
%endif

%endif

%changelog
* Tue Aug  6 2024 Michael Matz <matz@suse.com>
- Update to version 2.43:
  * new .base64 pseudo-op, allowing base64 encoded data as strings
  * Intel APX: add support for CFCMOV, CCMP, CTEST, zero-upper, NF
    (APX_F now fully supported)
  * x86 Intel syntax now warns about more mnemonic suffixes
  * macros and .irp/.irpc/.rept bodies can use \+ to get at number
    of times the macro/body was executed
  * aarch64: support 'armv9.5-a' for -march, add support for LUT
    and LUT2
  * s390: base register operand in D(X,B) and D(L,B) can now be
    omitted (ala 'D(X,)'); warn when register type doesn't match
    operand type (use option
    'warn-regtype-mismatch=[strict|relaxed|no]' to adjust)
  * riscv: support various extensions: Zacas, Zcmp, Zfbfmin,
    Zvfbfmin, Zvfbfwma, Smcsrind/Sscsrind, XCvMem, XCvBi, XCvElw,
    XSfCease, all at version 1.0;
    remove support for assembly of privileged spec 1.9.1 (linking
    support remains)
  * arm: remove support for some old co-processors: Maverick and FPA
  * mips: '--trap' now causes either trap or breakpoint instructions
    to be emitted as per current ISA, instead of always using trap
    insn and failing when current ISA was incompatible with that
  * LoongArch: accept .option pseudo-op for fine-grained control
    of assembly code options; add support for DT_RELR
  * readelf: now displays RELR relocations in full detail;
    add -j/--display-section to show just those section(s) content
    according to their type
  * objdump/readelf now dump also .eh_frame_hdr (when present) when
    dumping .eh_frame
  * gprofng: add event types for AMD Zen3/Zen4 and Intel Ice Lake
    processors; add minimal support for riscv
  * linker:
  - put .got and .got.plt into relro segment
  - add -z isa-level-report=[none|all|needed|used] to the x86 ELF
    linker to report needed and used x86-64 ISA levels
  - add --rosegment option which changes the -z separate-code
    option so that only one read-only segment is created (instead
    of two)
  - add --section-ordering-file <FILE> option to add extra
    mapping of input sections to output sections
  - add -plugin-save-temps to store plugin intermediate files
    permanently
- Removed binutils-2.42.tar.bz2, binutils-2.42-branch.diff.gz.
- Added binutils-2.43.tar.bz2, binutils-2.43-branch.diff.gz.
- Removed upstream patch riscv-no-relax.patch.
- Rebased ld-relro.diff and binutils-revert-rela.diff.
* Thu Jun 13 2024 Andreas Schwab <schwab@suse.de>
- binutils-pr22868.diff: Remove obsolete patch
- Undefine _FORTIFY_SOURCE when running checks
* Wed May  1 2024 Bernhard Wiedemann <bwiedemann@suse.com>
- Allow to disable profiling
* Thu Feb 22 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Wed Feb 21 2024 Andreas Schwab <schwab@suse.de>
- riscv-no-relax.patch: RISC-V: Don't generate branch/jump relocation if
  symbol is local when no-relax
* Mon Feb  5 2024 Michael Matz <matz@suse.com>
- Add binutils-disable-code-arch-error.diff to demote an
  error about swapped .arch/.code directives to a warning.
  It happens in the wild.
* Tue Jan 30 2024 Michael Matz <matz@suse.com>
- Update to version 2.42:
  * Add support for many aarch64 extensions: SVE2.1, SME2.1, B16B16,
  RASv2, LSE128, GCS, CHK, SPECRES2, LRCPC3, THE, ITE, D128, XS and
  flags to enable them: '+fcma', '+jscvt', '+frintts', '+flagm2',
  '+rcpc2' and '+wfxt'
  * Add experimantal support for GAS to synthesize call-frame-info for
  some hand-written asm (--scfi=experimental) on x86-64.
  * Add support for more x86-64 extensions: APX: 32 GPRs, NDD, PUSH2/POP2,
  PUSHP/POPP; USER_MSR, AVX10.1, PBNDKB, SM4, SM3, SHA512, AVX-VNNI-INT16.
  * Add support for more RISC-V extensions: T-Head v2.3.0, CORE-V v1.0,
  SiFive VCIX v1.0.
  * BPF assembler: ';' separates statements now, and does not introduce
  line comments anymore (use '#' or '//' for this).
  * x86-64 ld: Add '-z mark-plt/-z nomark-plt' to mark PLT entries with
  dynamic tags.
  * risc-v ld: Add '--[no-]check-uleb128'.
  * New linker script directive: REVERSE, to be combined with SORT_BY_NAME
  or SORT_BY_INIT_PRIORITY, reverses the generated order.
  * New linker options --warn-execstack-objects (warn only about execstack
  when input object files request it), and --error-execstack plus
  - -error-rxw-segments to convert the existing warnings into errors.
  * objdump: Add -Z/--decompress to be used with -s/--full-contents to
  decompress section contents before displaying.
  * readelf: Add --extra-sym-info to be used with --symbols (currently
  prints section name of references section index).
  * objcopy: Add --set-section-flags for x86_64 to include
  SHF_X86_64_LARGE.
  * s390 disassembly: add target-specific disasm option 'insndesc',
  as in "objdump -M insndesc" to display an instruction description
  as comment along with the disassembly.
- Add binutils-2.42-branch.diff.gz.
- Rebased s390-biarch.diff.
- Adjusted binutils-revert-hlasm-insns.diff,
  binutils-revert-plt32-in-branches.diff and binutils-revert-rela.diff
  for upstream changes.
- Removed binutils-2.41-branch.diff.gz, binutils-2.41.tar.bz2,
  binutils-2.41-branch.diff.gz.
- Removed binutils-use-less-memory.diff, binutils-old-makeinfo.diff
  and riscv-relro.patch (all upstreamed).
- Removed add-ulp-section.diff, we use a different mechanism
  for live patching since a long time.
* Thu Nov  9 2023 Michael Matz <matz@suse.com>
- Add binutils-use-less-memory.diff to be a little nicer to 32bit
  userspace and huge links.  [bsc#1216908]
* Mon Sep 25 2023 Andreas Schwab <schwab@suse.de>
- riscv-relro.patch: RISC-V: Protect .got with relro
* Thu Sep 14 2023 Michael Matz <matz@suse.com>
- Add libzstd-devel to Requires of binutils-devel. (bsc#1215341)
* Wed Aug 16 2023 Michael Matz <matz@suse.com>
- Update to version 2.41 [PED-5778]:
  * The MIPS port now supports the Sony Interactive Entertainment Allegrex
  processor, used with the PlayStation Portable, which implements the MIPS
  II ISA along with a single-precision FPU and a few implementation-specific
  integer instructions.
  * Objdump's --private option can now be used on PE format files to display the
  fields in the file header and section headers.
  * New versioned release of libsframe: libsframe.so.1.  This release introduces
  versioned symbols with version node name LIBSFRAME_1.0.  This release also
  updates the ABI in an incompatible way: this includes removal of
  sframe_get_funcdesc_with_addr API, change in the behavior of
  sframe_fre_get_ra_offset and sframe_fre_get_fp_offset APIs.
  * SFrame Version 2 is now the default (and only) format version supported by
  gas, ld, readelf and objdump.
  * Add command-line option, --strip-section-headers, to objcopy and strip to
  remove ELF section header from ELF file.
  * The RISC-V port now supports the following new standard extensions:
  - Zicond (conditional zero instructions)
  - Zfa (additional floating-point instructions)
  - Zvbb, Zvbc, Zvkg, Zvkned, Zvknh[ab], Zvksed, Zvksh, Zvkn, Zvknc, Zvkng,
    Zvks, Zvksc, Zvkg, Zvkt (vector crypto instructions)
  * The RISC-V port now supports the following vendor-defined extensions:
  - XVentanaCondOps
  * Add support for Intel FRED, LKGS and AMX-COMPLEX instructions.
  * A new .insn directive is recognized by x86 gas.
  * Add SME2 support to the AArch64 port.
  * The linker now accepts a command line option of --remap-inputs
  <PATTERN>=<FILE> to relace any input file that matches <PATTERN> with
  <FILE>.  In addition the option --remap-inputs-file=<FILE> can be used to
  specify a file containing any number of these remapping directives.
  * The linker command line option --print-map-locals can be used to include
  local symbols in a linker map.  (ELF targets only).
  * For most ELF based targets, if the --enable-linker-version option is used
  then the version of the linker will be inserted as a string into the .comment
  section.
  * The linker script syntax has a new command for output sections: ASCIZ "string"
  This will insert a zero-terminated string at the current location.
  * Add command-line option, -z nosectionheader, to omit ELF section
  header.
- Removed obsolete patches: binutils-2.40-branch.diff.gz,
  riscv-dynamic-tls-reloc-pie.patch, riscv-pr22263-1.patch,
  extensa-gcc-4_3-fix.diff .
- Add binutils-2.41-branch.diff.gz .
- Add binutils-old-makeinfo.diff for SLE-12 and older.
- Rebased aarch64-common-pagesize.patch and binutils-revert-rela.diff .
- Contains fixes for these non-CVEs (not security bugs per upstreams
  SECURITY.md):
  * bsc#1209642 aka CVE-2023-1579 aka PR29988
  * bsc#1210297 aka CVE-2023-1972 aka PR30285
  * bsc#1210733 aka CVE-2023-2222 aka PR29936
  * bsc#1213458 aka CVE-2021-32256 aka PR105039 (gcc)
  * bsc#1214565 aka CVE-2020-19726 aka PR26240
  * bsc#1214567 aka CVE-2022-35206 aka PR29290
  * bsc#1214579 aka CVE-2022-35205 aka PR29289
  * bsc#1214580 aka CVE-2022-44840 aka PR29732
  * bsc#1214604 aka CVE-2022-45703 aka PR29799
  * bsc#1214611 aka CVE-2022-48065 aka PR29925
  * bsc#1214619 aka CVE-2022-48064 aka PR29922
  * bsc#1214620 aka CVE-2022-48063 aka PR29924
  * bsc#1214623 aka CVE-2022-47696 aka PR29677
  * bsc#1214624 aka CVE-2022-47695 aka PR29846
  * bsc#1214625 aka CVE-2022-47673 aka PR29876
* Thu Jul 13 2023 Michael Matz <matz@suse.com>
- Add binutils-disable-dt-relr.sh for an compatibility problem
  caused by binutils-revert-rela.diff in SLE codestreams.
  Needed for update of glibc as that would otherwise pick up
  the broken relative relocs support.  [bsc#1213282, PED-1435]
- This only existed only for a very short while in SLE-15, as the main
  variant in devel:gcc subsumed this in binutils-revert-rela.diff.
  Hence:
- Remove binutils-disable-dt-relr.sh as subsumed.
* Tue May 30 2023 Andreas Schwab <schwab@suse.de>
- riscv-dynamic-tls-reloc-pie.patch: Backport for PR ld/22263 and PR
  ld/25694
- riscv-pr22263-1.patch: Backport for PR ld/22263
* Wed Apr 12 2023 Martin Liška <mliska@suse.cz>
- Rebase branch patch (includes fix for PR30281).
* Tue Mar 21 2023 Martin Liška <mliska@suse.cz>
- Document fixed CVEs:
  * bnc#1208037 aka CVE-2023-25588 aka PR29677
  * bnc#1208038 aka CVE-2023-25587 aka PR29846
  * bnc#1208040 aka CVE-2023-25585 aka PR29892
  * bnc#1208409 aka CVE-2023-0687 aka PR29444
* Thu Mar 16 2023 Richard Biener <rguenther@suse.com>
- Enable bpf-none cross target and add bpf-none to the multitarget
  set of supported targets.
* Wed Mar  8 2023 Michael Matz <matz@suse.com>
- Disable packed-relative-relocs for old codestreams.  They generate
  buggy relocations when binutils-revert-rela.diff is active.
  [bsc#1206556]
* Thu Feb 23 2023 Martin Liška <mliska@suse.cz>
- Disable ZSTD debug section compress by default.
* Tue Feb 21 2023 Martin Liška <mliska@suse.cz>
- Enable zstd compression algorithm (instead of zlib)
  for debug info sections by default.
* Mon Jan 30 2023 Martin Liška <mliska@suse.cz>
- Pack libgprofng only for supported platforms.
* Fri Jan 27 2023 Martin Liška <mliska@suse.cz>
- Remove upstreamed patch binutils-maxpagesize.diff.
* Fri Jan 27 2023 Martin Liška <mliska@suse.cz>
- Rebase binutils-2.40-branch.diff.gz as it includes fix for PR30043.
- Move libgprofng-related libraries to the proper locations (packages).
- Add --without=bootstrap for skipping of bootstrap (faster testing
  of the package).
* Tue Jan 24 2023 Richard Biener <rguenther@suse.com>
- Remove broken arm32-avoid-copyreloc.patch to fix [gcc#108515]
* Mon Jan 16 2023 Martin Liška <mliska@suse.cz>
- Update to version 2.40:
  * Objdump has a new command line option --show-all-symbols which will make it
  display all symbols that match a given address when disassembling.  (Normally
  only the first symbol that matches an address is shown).
  * Add --enable-colored-disassembly configure time option to enable colored
  disassembly output by default, if the output device is a terminal.  Note,
  this configure option is disabled by default.
  * DCO signed contributions are now accepted.
  * objcopy --decompress-debug-sections now supports zstd compressed debug
  sections.  The new option --compress-debug-sections=zstd compresses debug
  sections with zstd.
  * addr2line and objdump --dwarf now support zstd compressed debug sections.
  * The dlltool program now accepts --deterministic-libraries and
  - -non-deterministic-libraries as command line options to control whether or
  not it generates deterministic output libraries.  If neither of these options
  are used the default is whatever was set when the binutils were configured.
  * readelf and objdump now have a newly added option --sframe which dumps the
  SFrame section.
  * Add support for Intel RAO-INT instructions.
  * Add support for Intel AVX-NE-CONVERT instructions.
  * Add support for Intel MSRLIST instructions.
  * Add support for Intel WRMSRNS instructions.
  * Add support for Intel CMPccXADD instructions.
  * Add support for Intel AVX-VNNI-INT8 instructions.
  * Add support for Intel AVX-IFMA instructions.
  * Add support for Intel PREFETCHI instructions.
  * Add support for Intel AMX-FP16 instructions.
  * gas now supports --compress-debug-sections=zstd to compress
  debug sections with zstd.
  * Add --enable-default-compressed-debug-sections-algorithm={zlib,zstd}
  that selects the default compression algorithm
  for --enable-compressed-debug-sections.
  * Add support for various T-Head extensions (XTheadBa, XTheadBb, XTheadBs,
  XTheadCmo, XTheadCondMov, XTheadFMemIdx, XTheadFmv, XTheadInt, XTheadMemIdx,
  XTheadMemPair, XTheadMac, and XTheadSync) from version 2.0 of the T-Head
  ISA manual, which are implemented in the Allwinner D1.
  * Add support for the RISC-V Zawrs extension, version 1.0-rc4.
  * Add support for Cortex-X1C for Arm.
  * New command line option --gsframe to generate SFrame unwind information
  on x86_64 and aarch64 targets.
  * The linker has a new command line option to suppress the generation of any
  warning or error messages.  This can be useful when there is a need to create
  a known non-working binary.  The option is -w or --no-warnings.
  * ld now supports zstd compressed debug sections.  The new option
  - -compress-debug-sections=zstd compresses debug sections with zstd.
  * Add --enable-default-compressed-debug-sections-algorithm={zlib,zstd}
  that selects the default compression algorithm
  for --enable-compressed-debug-sections.
  * Remove support for -z bndplt (MPX prefix instructions).
- Rebased patches: add-ulp-section.diff, ld-relro.diff, binutils-revert-plt32-in-branches.diff,
  cross-avr-size.patch.
- Removed patch: binutils-pr29482.diff.
- New patch: extensa-gcc-4_3-fix.diff.
- Includes fixes for these CVEs:
  * bnc#1206080 aka CVE-2022-4285 aka PR29699
- Enable by default: --enable-colored-disassembly.
* Sat Dec 10 2022 Dirk Müller <dmueller@suse.com>
- fix build on x86_64_vX platforms
* Tue Oct 25 2022 Michael Matz <matz@suse.com>
- Add binutils-maxpagesize.diff for a problem on old code
  streams, where we would generate too large binaries.
* Tue Oct 25 2022 Andreas Schwab <schwab@suse.de>
- s390-pic-dso.diff: use %%pB instead of %%B
* Mon Oct 17 2022 Michael Matz <matz@suse.com>
- SLE toolchain update of binutils.  Update to 2.39 from 2.37,
  which means obsoleting and hence removing these patches:
  binutils-add-efi-aarch64-1.diff, binutils-add-efi-aarch64-2.diff,
  binutils-add-efi-aarch64-3.diff, binutils-fix-keepdebug.diff,
  binutils-add-z16-name.diff.
  Implements [jsc#SLE-25046, jsc#PED-2029, jsc#PED-2035, jsc#PED-2033,
  jsc#PED-2030, jsc#PED-2038, jsc#PED-2032, jsc#PED-2034, jsc#PED-2031,
  jsc#SLE-25047]
- This fixes these CVEs relative to 2.37:
  [bsc#1188374, bsc#1185597] aka (GCC) PR99935 aka CVE-2021-3648
  [bsc#1193929] aka PR28694 aka CVE-2021-45078
  [bsc#1194783] aka (GCC) PR98886 aka CVE-2021-46195
  [bsc#1197592] aka (GCC) PR105039 aka CVE-2022-27943
  [bsc#1202966] aka PR29289 aka CVE-2022-38126
  [bsc#1202967] aka PR29290 aka CVE-2022-38127
  [bsc#1202969] aka CVE-2021-3826
* Fri Oct 14 2022 Dirk Müller <dmueller@suse.com>
- add arm32-avoid-copyreloc.patch for PR16177 (bsc#1200962)
* Fri Aug 26 2022 Michael Matz <matz@suse.com>
- Add binutils-pr29482.diff for PR29482, aka CVE-2022-38533
  [bsc#1202816]
* Wed Aug 10 2022 Martin Liška <mliska@suse.cz>
- Rebase binutils-2.39-branch.diff.gz that contains fix for PR29451.
* Mon Aug  8 2022 Martin Liška <mliska@suse.cz>
- Add binutils-2.39-branch.diff.gz.
- Explicitly enable --enable-warn-execstack=yes and	--enable-warn-rwx-segments=yes.
- Add gprofng subpackage.
* Sat Aug  6 2022 Martin Liška <mliska@suse.cz>
- Update to binutils 2.39:
  * The ELF linker will now generate a warning message if the stack is made
    executable.  Similarly it will warn if the output binary contains a
    segment with all three of the read, write and execute permission
    bits set.  These warnings are intended to help developers identify
    programs which might be vulnerable to attack via these executable
    memory regions.
    The warnings are enabled by default but can be disabled via a command
    line option.  It is also possible to build a linker with the warnings
    disabled, should that be necessary.
  * The ELF linker now supports a --package-metadata option that allows
    embedding a JSON payload in accordance to the Package Metadata
    specification.
  * In linker scripts it is now possible to use TYPE=<type> in an output
    section description to set the section type value.
  * The objdump program now supports coloured/colored syntax
    highlighting of its disassembler output for some architectures.
    (Currently: AVR, RiscV, s390, x86, x86_64).
  * The nm program now supports a --no-weak/-W option to make it ignore
    weak symbols.
  * The readelf and objdump programs now support a -wE option to prevent
    them from attempting to access debuginfod servers when following
    links.
  * The objcopy program's --weaken, --weaken-symbol, and
  - -weaken-symbols options now works with unique symbols as well.
- Rebase binutils-compat-old-behaviour.diff, binutils-revert-hlasm-insns.diff,
  binutils-revert-plt32-in-branches.diff and remove binutils-2.38-branch.diff.gz.
- For now use --disable-gprofng.
- Includes fixes for these CVEs:
  bnc#1142579 aka CVE-2019-1010204 aka PR23765
* Mon Jun 13 2022 Michael Matz <matz@suse.com>
  (Fake entry from SLE for tracking purposes:)
- For building shim 15.6~rc1 (and later versions) aarch64 image, objcopy
  needs to support efi-app-aarch64 target. (bsc#1198458)
  Adds binutils-add-efi-aarch64-1.diff,
  binutils-add-efi-aarch64-2.diff, binutils-add-efi-aarch64-3.diff .
* Wed May 25 2022 Martin Liška <mliska@suse.cz>
- Use https for variosu links.
* Wed May 25 2022 Martin Liška <mliska@suse.cz>
- Update binutils-2.38-branch.diff.gz (to 93054037f1e304e)
  in order to include PR29087.
* Mon May  9 2022 Andreas Schwab <schwab@suse.de>
- Enable multitarget build on riscv64
- On SLE15 and later, use make -Oline to synchronize configure output by
  lines
* Fri May  6 2022 Michael Matz <matz@suse.com>
  (Fake entry from SLE for tracking purposes:)
- Add binutils-fix-keepdebug.diff for fix bsc#1191908, a problem
  in crash not accepting some of our .ko.debug files.
* Wed May  4 2022 Martin Liška <mliska@suse.cz>
- Renumber Sources.
* Wed May  4 2022 Martin Liška <mliska@suse.cz>
- Fix ExcludeArch for ppc.
* Wed May  4 2022 Martin Liška <mliska@suse.cz>
- Make multibuild utilize only the main binutils.spec file.
- Remove not needed README.First-for.SUSE.packagers, pre_checkin.sh.
* Mon May  2 2022 Martin Liška <mliska@suse.cz>
- Start using _multibuild for cross binutils.
* Mon Apr 25 2022 Michael Matz <matz@suse.com>
- Add binutils-revert-rela.diff to revert back to old behaviour
  of not ignoring the in-section content of to be relocated
  fields on x86-64, even though that's a RELA architecture.
  Compatibility with buggy object files generated by old tools.
  [bsc#1198422]
  (forward port from SLE)
* Mon Apr 11 2022 Michael Matz <matz@suse.com>
- Update binutils-2.38-branch.diff.gz (to c210342d7f5) to include
  recognition of 'z16' name for 'arch14' on s390.  [bsc#1198237]
* Mon Apr 11 2022 Michael Matz <matz@suse.com>
  (Fake entry from SLE for tracking purposes:)
- Add binutils-add-z16-name.diff so that the now official name
  z16 for arch14 is recognized.  [bsc#1198237]
* Mon Mar 21 2022 Marcus Meissner <meissner@suse.com>
- Add usage of a SUSE_ZNOW environment variable which allows switching
  on "-z now" by default using "export SUSE_ZNOW=1", similar to
  the SUSE_ASNEEDED variable.  Adds binutils-znow.patch.
* Thu Mar 10 2022 Wolfgang Bauer <wbauer@tmo.at>
- Update binutils-skip-rpaths.patch: add back fix for boo#1191473,
  which got lost in the update to 2.38.
* Fri Mar  4 2022 Martin Liška <mliska@suse.cz>
- Update binutils-2.38-branch.diff.gz in order to include PR28879.
* Tue Mar  1 2022 Michael Matz <matz@suse.com>
- From Stefan Brüns <stefan.bruens@rwth-aachen.de>:
  * Install symlinks for all target specific tools on
    arm-eabi-none [bsc#1185712]
* Thu Feb 24 2022 Martin Liška <mliska@suse.cz>
- Do not re-generate ld/ldlex.c, ld/ldgram.c, ld/ldgram.h and verify
  that corresponding flex/bison files are not modified by a patch.
* Thu Feb 24 2022 Martin Liška <mliska@suse.cz>
- Use verbose mode for make for cross compilers.
* Wed Feb 23 2022 Michael Matz <matz@suse.com>
- Make it build on SLE-11 again.
* Tue Feb 22 2022 Martin Liška <mliska@suse.cz>
- Use verbose mode for make.
* Sat Feb 12 2022 Martin Liška <mliska@suse.cz>
- Update to binutils 2.38:
  * elfedit: Add --output-abiversion option to update ABIVERSION.
  * Add support for the LoongArch instruction set.
  * Tools which display symbols or strings (readelf, strings, nm, objdump)
    have a new command line option which controls how unicode characters are
    handled.  By default they are treated as normal for the tool.  Using
  - -unicode=locale will display them according to the current locale.
    Using --unicode=hex will display them as hex byte values, whilst
  - -unicode=escape will display them as escape sequences.  In addition
    using --unicode=highlight will display them as unicode escape sequences
    highlighted in red (if supported by the output device).
  * readelf -r dumps RELR relative relocations now.
  * Support for efi-app-aarch64, efi-rtdrv-aarch64 and efi-bsdrv-aarch64 has been
    added to objcopy in order to enable UEFI development using binutils.
  * ar: Add --thin for creating thin archives. -T is a deprecated alias without
    diagnostics. In many ar implementations -T has a different meaning, as
    specified by X/Open System Interface.
  * Add support for AArch64 system registers that were missing in previous
    releases.
  * Add support for the LoongArch instruction set.
  * Add a command-line option, -muse-unaligned-vector-move, for x86 target
    to encode aligned vector move as unaligned vector move.
  * Add support for Cortex-R52+ for Arm.
  * Add support for Cortex-A510, Cortex-A710, Cortex-X2 for AArch64.
  * Add support for Cortex-A710 for Arm.
  * Add support for Scalable Matrix Extension (SME) for AArch64.
  * The --multibyte-handling=[allow|warn|warn-sym-only] option tells the
    assembler what to when it encoutners multibyte characters in the input.  The
    default is to allow them.  Setting the option to "warn" will generate a
    warning message whenever any multibyte character is encountered.  Using the
    option to "warn-sym-only" will make the assembler generate a warning whenever a
    symbol is defined containing multibyte characters.  (References to undefined
    symbols will not generate warnings).
  * Outputs of .ds.x directive and .tfloat directive with hex input from
    x86 assembler have been reduced from 12 bytes to 10 bytes to match the
    output of .tfloat directive.
  * Add support for 'armv8.8-a', 'armv9-a', 'armv9.1-a', 'armv9.2-a' and
    'armv9.3-a' for -march in AArch64 GAS.
  * Add support for 'armv8.7-a', 'armv8.8-a', 'armv9-a', 'armv9.1-a',
    'armv9.2-a' and 'armv9.3-a' for -march in Arm GAS.
  * Add support for Intel AVX512_FP16 instructions.
  * Add -z pack-relative-relocs/-z no pack-relative-relocs to x86 ELF
    linker to pack relative relocations in the DT_RELR section.
  * Add support for the LoongArch architecture.
  * Add -z indirect-extern-access/-z noindirect-extern-access to x86 ELF
    linker to control canonical function pointers and copy relocation.
  * Add --max-cache-size=SIZE to set the the maximum cache size to SIZE
    bytes.
- Add binutils-2.38-branch.diff.gz.
- Removed deletion of man pages as they should be properly packages
  in tarball.
- Rebased patches: aarch64-common-pagesize.patch, add-ulp-section.diff,
  binutils-bfd_h.patch, binutils-revert-nm-symversion.diff,
  binutils-revert-plt32-in-branches.diff, binutils-skip-rpaths.patch
  and binutils-compat-old-behaviour.diff.
* Fri Feb  4 2022 Matwey Kornilov <matwey.kornilov@gmail.com>
- Enable PRU architecture for AM335x CPU (Beagle Bone Black board)
* Thu Jan 27 2022 Dirk Müller <dmueller@suse.com>
- use fdupes on datadir
- remove RPM_BUILD_ROOT usage and other cleanups
* Fri Nov 12 2021 Martin Liška <mliska@suse.cz>
- Rebase binutils-2.37-branch.diff: fixes PR28494.
* Fri Nov  5 2021 Michael Matz <matz@suse.com>
- Add binutils-revert-hlasm-insns.diff for compatibility on old
  code stream that expect 'brcl 0,label' to not be disassembled
  as 'jgnop label' on s390x.  [bsc#1192267]
* Wed Nov  3 2021 Martin Liška <mliska@suse.cz>
- Rebase binutils-2.37-branch.diff: fixes PR28523 aka boo#1188941.
* Tue Nov  2 2021 Michael Matz <matz@suse.com>
- Fix empty man-pages from broken release tarball [PR28144].
* Mon Nov  1 2021 Martin Liška <mliska@suse.cz>
- Update binutils-skip-rpaths.patch with contained a memory corruption
  (boo#1191473).
* Fri Oct  8 2021 Michael Matz <matz@suse.com>
- Configure with --disable-x86-used-note on old code streams.
- Disable libalternatives temporarily for build cycle reasons.
- make TARGET-bfd=headers again, we patch bfd-in.h
- This state submitted to SLE12 and SLE15 code streams for annual
  toolchain update. [jsc#PM-2767, jsc#SLE-21561, jsc#SLE-19618]
- Bump binutils-2.37-branch.diff to 66d5c7003, to include fixes for
  PR28422, PR28192, PR28391.  Also adds some s390x arch14
  instructions [jsc#SLE-18637].
* Fri Sep 10 2021 Stefan Schubert schubi@suse.de
- Using libalternatives instead of update-alternatives.
* Wed Sep  8 2021 Michael Matz <matz@suse.com>
- Adjust for testsuite fails on older products that configure
  binutils in different ways, adds  binutils-compat-old-behaviour.diff
  and adjusts binutils-revert-nm-symversion.diff and
  binutils-revert-plt32-in-branches.diff.
* Tue Aug  3 2021 Martin Liška <mliska@suse.cz>
- Bump binutils-2.37-branch.diff: fixes PR28138.
* Thu Jul 22 2021 Martin Liška <mliska@suse.cz>
- Use LTO & PGO build.
* Thu Jul 22 2021 Martin Liška <mliska@suse.cz>
- Update to binutils 2.37:
  * The GNU Binutils sources now requires a C99 compiler and library to
    build.
  * Support for the arm-symbianelf format has been removed.
  * Support for Realm Management Extension (RME) for AArch64 has been
    added.
  * A new linker option '-z report-relative-reloc' for x86 ELF targets
    has been added to report dynamic relative relocations.
  * A new linker option '-z start-stop-gc' has been added to disable
    special treatment of __start_*/__stop_* references when
  - -gc-sections.
  * A new linker options '-Bno-symbolic' has been added which will
    cancel the '-Bsymbolic' and '-Bsymbolic-functions' options.
  * The readelf tool has a new command line option which can be used to
    specify how the numeric values of symbols are reported.
  - -sym-base=0|8|10|16 tells readelf to display the values in base 8,
    base 10 or base 16.  A sym base of 0 represents the default action
    of displaying values under 10000 in base 10 and values above that in
    base 16.
  * A new format has been added to the nm program.  Specifying
    '--format=just-symbols' (or just using -j) will tell the program to
    only display symbol names and nothing else.
  * A new command line option '--keep-section-symbols' has been added to
    objcopy and strip.  This stops the removal of unused section symbols
    when the file is copied.  Removing these symbols saves space, but
    sometimes they are needed by other tools.
  * The '--weaken', '--weaken-symbol' and '--weaken-symbols' options
    supported by objcopy now make undefined symbols weak on targets that
    support weak symbols.
  * Readelf and objdump can now display and use the contents of .debug_sup
    sections.
  * Readelf and objdump will now follow links to separate debug info
    files by default.  This behaviour can be stopped via the use of the
    new '-wN' or '--debug-dump=no-follow-links' options for readelf and
    the '-WN' or '--dwarf=no-follow-links' options for objdump.  Also
    the old behaviour can be restored by the use of the
    '--enable-follow-debug-links=no' configure time option.
    The semantics of the =follow-links option have also been slightly
    changed.  When enabled, the option allows for the loading of symbol
    tables and string tables from the separate files which can be used
    to enhance the information displayed when dumping other sections,
    but it does not automatically imply that information from the
    separate files should be displayed.
    If other debug section display options are also enabled (eg
    '--debug-dump=info') then the contents of matching sections in both
    the main file and the separate debuginfo file *will* be displayed.
    This is because in most cases the debug section will only be present
    in one of the files.
    If however non-debug section display options are enabled (eg
    '--sections') then the contents of matching parts of the separate
    debuginfo file will *not* be displayed.  This is because in most
    cases the user probably only wanted to load the symbol information
    from the separate debuginfo file.  In order to change this behaviour
    a new command line option --process-links can be used.  This will
    allow di0pslay options to applied to both the main file and any
    separate debuginfo files.
  * Nm has a new command line option: '--quiet'.  This suppresses "no
    symbols" diagnostic.
- Includes fixes for these CVEs:
  bnc#1181452 aka CVE-2021-20197 aka PR26945
  bnc#1183511 aka CVE-2021-20284 aka PR26931
  bnc#1184519 aka CVE-2021-20294 aka PR26929
  bnc#1184620 aka CVE-2021-3487 aka PR26946
  bnc#1184794 aka CVE-2020-35448 aka PR26574
- Also fixes:
  bsc#1183909 - slow performance of stripping some binaries
- Rebased patches: binutils-build-as-needed.diff, binutils-fix-abierrormsg.diff,
  binutils-fix-invalid-op-errata.diff, binutils-fix-relax.diff,
  binutils-revert-nm-symversion.diff, binutils-revert-plt32-in-branches.diff
- Removed patches (are in upstream): ppc-ensure-undef-dynamic-weak-undefined.patch and
  ppc-use-local-plt.patch.
- Add binutils-2.37-branch.diff.gz.
* Fri May  7 2021 Andreas Schwab <schwab@suse.de>
- ppc-ensure-undef-dynamic-weak-undefined.patch: PPC: ensure_undef_dynamic
  on weak undef only in plt
- ppc-use-local-plt.patch: PowerPC use_local_plt (prerequisite for above
  patch)
* Fri Mar 26 2021 Martin Liška <mliska@suse.cz>
- Update 2.36 branch diff which fixes PR27587.
* Wed Mar  3 2021 Martin Liška <mliska@suse.cz>
- Do not run make TARGET-bfd=headers separately.
* Mon Mar  1 2021 Martin Liška <mliska@suse.cz>
- Bump 2.36 branch diff (includes fix for PR27441 aka bsc#1182252).
* Thu Feb  4 2021 Martin Liška <mliska@suse.cz>
- Bump 2.36 branch diff.
* Wed Feb  3 2021 Martin Liška <mliska@suse.cz>
- Update 2.36 branch diff which should fix PR27311 completely.
  It fixes also PR27284.
- Remove temporary fix 0001-PR27311-ld.bfd-symbol-from-plugin-undefined-referenc.patch.
* Tue Feb  2 2021 Martin Liška <mliska@suse.cz>
- Add temporary upstream fix for PR27311
  0001-PR27311-ld.bfd-symbol-from-plugin-undefined-referenc.patch.
* Sun Jan 24 2021 Martin Liška <mliska@suse.cz>
- Update to binutils 2.36:
  New features in the Assembler:
    General:
  * When setting the link order attribute of ELF sections, it is now
    possible to use a numeric section index instead of symbol name.
  * Added a .nop directive to generate a single no-op instruction in
    a target neutral manner.  This instruction does have an effect on
    DWARF line number generation, if that is active.
  * Removed --reduce-memory-overheads and --hash-size as gas now
    uses hash tables that can be expand and shrink automatically.
    X86/x86_64:
  * Add support for AVX VNNI, HRESET, UINTR, TDX, AMX and Key
    Locker instructions.
  * Support non-absolute segment values for lcall and ljmp.
  * Add {disp16} pseudo prefix to x86 assembler.
  * Configure with --enable-x86-used-note by default for Linux/x86.
    ARM/AArch64:
  * Add support for Cortex-A78, Cortex-A78AE and Cortex-X1,
    Cortex-R82, Neoverse V1, and Neoverse N2 cores.
  * Add support for ETMv4 (Embedded Trace Macrocell), ETE (Embedded
    Trace Extension), TRBE (Trace Buffer Extension), CSRE (Call
    Stack Recorder Extension) and BRBE (Branch Record Buffer
    Extension) system registers.
  * Add support for Armv8-R and Armv8.7-A ISA extensions.
  * Add support for DSB memory nXS barrier, WFET and WFIT
    instruction for Armv8.7.
  * Add support for +csre feature for -march. Add CSR PDEC
    instruction for CSRE feature in AArch64.
  * Add support for +flagm feature for -march in Armv8.4 AArch64.
  * Add support for +ls64 feature for -march in Armv8.7
    AArch64. Add atomic 64-byte load/store instructions for this
    feature.
  * Add support for +pauth (Pointer Authentication) feature for
  - march in AArch64.
    New features in the Linker:
  * Add --error-handling-script=<NAME> command line option to allow
    a helper script to be invoked when an undefined symbol or a
    missing library is encountered.  This option can be suppressed
    via the configure time switch: --enable-error-handling-script=no.
  * Add -z x86-64-{baseline|v[234]} to the x86 ELF linker to mark
    x86-64-{baseline|v[234]} ISA level as needed.
  * Add -z unique-symbol to avoid duplicated local symbol names.
  * The creation of PE format DLLs now defaults to using a more
    secure set of DLL characteristics.
  * The linker now deduplicates the types in .ctf sections.  The new
    command-line option --ctf-share-types describes how to do this:
    its default value, share-unconflicted, produces the most compact
    output.
  * The linker now omits the "variable section" from .ctf sections
    by default, saving space.  This is almost certainly what you
    want unless you are working on a project that has its own
    analogue of symbol tables that are not reflected in the ELF
    symtabs.
  New features in other binary tools:
  * The ar tool's previously unused l modifier is now used for
    specifying dependencies of a static library. The arguments of
    this option (or --record-libdeps long form option) will be
    stored verbatim in the __.LIBDEP member of the archive, which
    the linker may read at link time.
  * Readelf can now display the contents of LTO symbol table
    sections when asked to do so via the --lto-syms command line
    option.
  * Readelf now accepts the -C command line option to enable the
    demangling of symbol names.  In addition the --demangle=<style>,
  - -no-demangle, --recurse-limit and --no-recurse-limit options
    are also now availale.
- Includes fixes for these CVEs:
  bnc#1179898 aka CVE-2020-16590 aka PR25821
  bnc#1179899 aka CVE-2020-16591 aka PR25822
  bnc#1179900 aka CVE-2020-16592 aka PR25823
  bnc#1179901 aka CVE-2020-16593 aka PR25827
  bnc#1179902 aka CVE-2020-16598 aka PR25840
  bnc#1179903 aka CVE-2020-16599 aka PR25842
  bnc#1180451 aka CVE-2020-35493 aka PR25307
  bnc#1180454 aka CVE-2020-35496 aka PR25308
  bnc#1180461 aka CVE-2020-35507 aka PR25308
- Rebase the following patches:
  * binutils-fix-relax.diff
  * binutils-revert-nm-symversion.diff
  * binutils-revert-plt32-in-branches.diff
- Add missing dependency on bc (ld.gold testsuite uses it).
- Use --enable-obsolete for cross builds as ia64 is deprecated now.
- Add binutils-2.36-branch.diff.gz.
* Fri Dec  4 2020 Michael Matz <matz@suse.com>
- Add binutils-fix-relax.diff to fix linking relaxation problems
  with old object files hitting some enterprise software. [bsc#1179341]
* Mon Nov 23 2020 Michael Matz <matz@suse.com>
- Update binutils-2.35-branch.diff.gz to commit 1c5243df:
  * Fixes PR26520, aka [bsc#1179036], a problem in addr2line with
    certain DWARF variable descriptions.
  * Also fixes PR26711, PR26656, PR26655, PR26929, PR26808, PR25878,
    PR26740, PR26778, PR26763, PR26685, PR26699, PR26902, PR26869,
    PR26711
  * The above includes fixes for dwo files produced by modern dwp,
    fixing several problems in the DWARF reader.
* Mon Oct 12 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Reapply spec file cleanup from format_spec_file
- Remove a SLE10 version check
* Mon Sep 21 2020 Martin Liška <mliska@suse.cz>
- Update to 2.35.1 and rebased branch diff:
  * This is a point release over the previous 2.35 version, containing bug
  fixes, and as an exception to the usual rule, one new feature.  The
  new feature is the support for a new directive in the assembler:
  ".nop".  This directive creates a single no-op instruction in whatever
  encoding is correct for the target architecture.  Unlike the .space or
  .fill this is a real instruction, and it does affect the generation of
  DWARF line number tables, should they be enabled.
* Tue Sep 15 2020 matz@suse.com
- Update binutils-2.35-branch.diff.gz to commit 23f268a0:
  * Add xBPF target
  * Fix various problems with DWARF 5 support in gas
- Toolchain module update for SLE15 [jsc#ECO-2373]
- Includes changes that were SLE-only in binutils-add-z15-name.diff
  for [bsc#1160590, jsc#SLE-7903 aka jsc#SLE-7464]
- Amend binutils-revert-plt32-in-branches.diff to adjust also new
  testcases.
* Sat Aug 15 2020 Martin Liška <mliska@suse.cz>
- Add binutils-2.35-branch.diff.gz: it includes fix for
  nm -B for objects compiled with -flto and -fcommon.
* Fri Aug  7 2020 matz@suse.com
- Add binutils-revert-nm-symversion.diff to be compatible with old
  output of nm relied on in scripts.
- Add binutils-fix-abierrormsg.diff to work around an eager (new)
  error message occuring without inputs and as-needed (affects
  nvme-cli build).
* Fri Jul 24 2020 Martin Liška <mliska@suse.cz>
- Update to binutils 2.35:
  * The asseembler can now produce DWARF-5 format line number tables.
  * Readelf now has a "lint" mode to enable extra checks of the files it is processing.
  * Readelf will now display "[...]" when it has to truncate a symbol name.
    The old behaviour - of displaying as many characters as possible, up to
    the 80 column limit - can be restored by the use of the --silent-truncation
    option.
  * The linker can now produce a dependency file listing the inputs that it
    has processed, much like the -M -MP option supported by the compiler.
- Regenerate add-ulp-section.diff with -p1 due to a fuzzing issue.
- Remove binutils-2.34-branch.diff.gz.
- Regenerate binutils-build-as-needed.diff due to a fuzzing issue.
- Regenerate binutils-fix-invalid-op-errata.diff as one hunk was upstreamed.
- Remove upstreamed patch binutils-pr25593.diff.
- Regenerate unit-at-a-time.patch due to a fuzzing issue.
- Regenerate binutils-revert-plt32-in-branches.diff.
* Wed Mar 25 2020 Martin Liška <mliska@suse.cz>
- Update binutils-2.34-branch.diff.gz.
* Fri Feb 28 2020 Martin Liška <mliska@suse.cz>
- Remove fix-try_load_plugin.patch as it is part
  of the updated binutils-2.34-branch.diff.gz patch.
* Wed Feb 26 2020 Richard Biener <rguenther@suse.com>
- Add binutils-pr25593.diff to fix DT_NEEDED order with -flto
  [bsc#1163744]
* Tue Feb 18 2020 Martin Liška <mliska@suse.cz>
- Update fix-try_load_plugin.patch to latest version.
* Tue Feb 18 2020 Martin Liška <mliska@suse.cz>
- Add fix-try_load_plugin.patch in order to fix fallback caused
  by backport for PR25355.
* Sat Feb  1 2020 Martin Liška <mliska@suse.cz>
- Update to binutils 2.34:
  * The disassembler (objdump --disassemble) now has an option to
    generate ascii art thats show the arcs between that start and end
    points of control flow instructions.
  * The binutils tools now have support for debuginfod.  Debuginfod is a
    HTTP service for distributing ELF/DWARF debugging information as
    well as source code.  The tools can now connect to debuginfod
    servers in order to download debug information about the files that
    they are processing.
  * The assembler and linker now support the generation of ELF format
    files for the Z80 architecture.
- Rename and get binutils-2.34-branch.diff.gz (boo#1160254).
- Rebase add-ulp-section.diff, binutils-revert-plt32-in-branches.diff,
  cross-avr-size.patch and binutils-skip-rpaths.patch.
- Add new subpackages for libctf and libctf-nobfd.
- Disable LTO due to boo#1163333.
- Includes fixes for these CVEs:
  bnc#1153768 aka CVE-2019-17451 aka PR25070
  bnc#1153770 aka CVE-2019-17450 aka PR25078
* Tue Jan  7 2020 Andreas Schwab <schwab@suse.de>
- Disable LTO during testsuite run
* Wed Nov 20 2019 matz@suse.com
- Add binutils-fix-invalid-op-errata.diff to fix various
  build fails on aarch64 (PR25210, bsc#1157755).
* Mon Nov 18 2019 matz@suse.com
- Add add-ulp-section.diff for user space live patching.
* Tue Oct 22 2019 Martin Liška <mliska@suse.cz>
- Update to binutils 2.33.1:
  * Adds support for the Arm Scalable Vector Extension version 2
    (SVE2) instructions, the Arm Transactional Memory Extension (TME)
    instructions and the Armv8.1-M Mainline and M-profile Vector
    Extension (MVE) instructions.
  * Adds support for the Arm Cortex-A76AE, Cortex-A77 and Cortex-M35P
    processors and the AArch64 Cortex-A34, Cortex-A65, Cortex-A65AE,
    Cortex-A76AE, and Cortex-A77 processors.
  * Adds a .float16 directive for both Arm and AArch64 to allow
    encoding of 16-bit floating point literals.
  * For MIPS, Add -m[no-]fix-loongson3-llsc option to fix (or not)
    Loongson3 LLSC Errata.  Add a --enable-mips-fix-loongson3-llsc=[yes|no]
    configure time option to set the default behavior. Set the default
    if the configure option is not used to "no".
  * The Cortex-A53 Erratum 843419 workaround now supports a choice of
    which workaround to use.  The option --fix-cortex-a53-843419 now
    takes an optional argument --fix-cortex-a53-843419[=full|adr|adrp]
    which can be used to force a particular workaround to be used.
    See --help for AArch64 for more details.
  * Add support for GNU_PROPERTY_AARCH64_FEATURE_1_BTI and
    GNU_PROPERTY_AARCH64_FEATURE_1_PAC  in ELF GNU program properties
    in the AArch64 ELF linker.
  * Add -z force-bti for AArch64 to enable GNU_PROPERTY_AARCH64_FEATURE_1_BTI
    on output while warning about missing GNU_PROPERTY_AARCH64_FEATURE_1_BTI
    on inputs and use PLTs protected with BTI.
  * Add -z pac-plt for AArch64 to pick PAC enabled PLTs.
  * Add --source-comment[=<txt>] option to objdump which if present,
    provides a prefix to source code lines displayed in a disassembly.
  * Add --set-section-alignment <section-name>=<power-of-2-align>
    option to objcopy to allow the changing of section alignments.
  * Add --verilog-data-width option to objcopy for verilog targets to
    control width of data elements in verilog hex format.
  * The separate debug info file options of readelf (--debug-dump=links
    and --debug-dump=follow) and objdump (--dwarf=links and
  - -dwarf=follow-links) will now display and/or follow multiple
    links if more than one are present in a file.  (This usually
    happens when gcc's -gsplit-dwarf option is used).
    In addition objdump's --dwarf=follow-links now also affects its
    other display options, so that for example, when combined with
  - -syms it will cause the symbol tables in any linked debug info
    files to also be displayed.  In addition when combined with
  - -disassemble the --dwarf= follow-links option will ensure that
    any symbol tables in the linked files are read and used when
    disassembling code in the main file.
  * Add support for dumping types encoded in the Compact Type Format
    to objdump and readelf.
- Includes fixes for these CVEs:
  bnc#1126826 aka CVE-2019-9077 aka PR1126826
  bnc#1126829 aka CVE-2019-9075 aka PR1126829
  bnc#1126831 aka CVE-2019-9074 aka PR24235
  bnc#1140126 aka CVE-2019-12972 aka PR23405
  bnc#1143609 aka CVE-2019-14444 aka PR24829
  bnc#1142649 aka CVE-2019-14250 aka PR90924
- Remove patches that are now included in the release:
  binutils-2.32-branch.diff.gz, binutils-fix-ld-segv.diff,
  binutils-pr24486.patch, riscv-abi-check.patch,
  rx-gas-padding-pr24464.patch.
- Add binutils-2.33-branch.diff.gz patch.
- Rebase binutils-revert-plt32-in-branches.diff and
  cross-avr-size.patch patch.
* Tue Oct 15 2019 matz@suse.com
- Add binutils-fix-ld-segv.diff to fix a segfault in ld
  when building some versions of pacemaker.  [bsc#1154025,
  bsc#1154016]
* Wed Oct  2 2019 matz@suse.com
- Add avr, epiphany and rx to target_list so that the common
  binutils can handle all objects we can create with crosses.
  [bsc#1152590]
* Mon Sep  9 2019 matz@suse.com
- Update to current 2.32 branch @7b468db3 adding
  binutils-2.32-branch.diff.gz [jsc#ECO-368].
- Includes fixes for these CVEs:
  bsc#1109412 aka CVE-2018-17358 aka PR23686
  bsc#1109413 aka CVE-2018-17359 aka PR23686
  bsc#1109414 aka CVE-2018-17360 aka PR23685
  bsc#1111996 aka CVE-2018-18309 aka PR23770
  bsc#1112534 aka CVE-2018-18484 aka GCC PR87636
  bsc#1112535 aka CVE-2018-18483 aka PR23767
  bsc#1113247 aka CVE-2018-18607 aka PR23805
  bsc#1113252 aka CVE-2018-18606 aka PR23806
  bsc#1113255 aka CVE-2018-18605 aka PR23804
  bsc#1116827 aka CVE-2018-17985 aka GCC PR87335
  bsc#1118830 aka CVE-2018-19932 aka PR23932
  bsc#1118831 aka CVE-2018-19931 aka PR23942
  bsc#1120640 aka CVE-2018-1000876 aka PR23994
  bsc#1121034 aka CVE-2018-20651 aka PR24041
  bsc#1121035 aka CVE-2018-20623 aka PR24049
  bsc#1121056 aka CVE-2018-20671 aka PR24005
  bsc#1142772 aka CVE-2019-1010180 aka PR23657
- Refresh s390-biarch.diff and
  binutils-revert-plt32-in-branches.diff .
- For the SLE12 package this also removes patches
  binutils-z13-1.diff, binutils-z13-2.diff,
  binutils-z13-3.diff, binutils-z13-4.diff and binutils-z13-5.diff .
* Sat Aug 31 2019 Dirk Mueller <dmueller@suse.com>
- enable xtensa architecture (Tensilica lc6 and related)
- Fix SUSE typo in README package name
* Mon Jul 22 2019 Martin Liška <mliska@suse.cz>
- Use -ffat-lto-objects in order to provide assembly for static libs
  (boo#1141913).
* Mon Jun  3 2019 matz@suse.com
  Fake entry for SLE12 package variant only:
- Add support for new z13 instructions. [fate#327074, jsc#SLE-6206,
  bsc#1137271]
  Adds patches binutils-z13-1.diff, binutils-z13-2.diff,
  binutils-z13-3.diff, binutils-z13-4.diff and binutils-z13-5.diff .
* Mon Apr 29 2019 Martin Liška <mliska@suse.cz>
- Add binutils-pr24486.patch: fix for PR24486 (boo#1133131 boo#1133232).
* Tue Apr 23 2019 Martin Liška <mliska@suse.cz>
- Add rx-gas-padding-pr24464.patch: fix for PR24464.
* Wed Apr  3 2019 Andreas Schwab <schwab@suse.de>
- riscv-abi-check.patch: Don't check ABI flags if no code section
* Tue Feb 19 2019 Martin Liška <mliska@suse.cz>
- Add binutils.keyring and verify signature.
* Tue Feb  5 2019 Martin Liška <mliska@suse.cz>
- Add disk and RAM (for ppc, ppc64 and ppc64le) constraint with _constraints.
* Mon Feb  4 2019 Martin Liška <mliska@suse.cz>
- Update to binutils 2.32:
  * The binutils now support for the C-SKY processor series.
  * The x86 assembler now supports a -mvexwig=[0|1] option to control
    encoding of VEX.W-ignored (WIG) VEX instructions.
    It also has a new -mx86-used-note=[yes|no] option to generate (or
    not) x86 GNU property notes.
  * The MIPS assembler now supports the Loongson EXTensions R2 (EXT2),
    the Loongson EXTensions (EXT) instructions, the Loongson Content
    Address Memory (CAM) ASE and the Loongson MultiMedia extensions
    Instructions (MMI) ASE.
  * The addr2line, c++filt, nm and objdump tools now have a default
    limit on the maximum amount of recursion that is allowed whilst
    demangling strings.  This limit can be disabled if necessary.
  * Objdump's --disassemble option can now take a parameter,
    specifying the starting symbol for disassembly.  Disassembly will
    continue from this symbol up to the next symbol or the end of the
    function.
  * The BFD linker will now report property change in linker map file
    when merging GNU properties.
  * The BFD linker's -t option now doesn't report members within
    archives, unless -t is given twice.  This makes it more useful
    when generating a list of files that should be packaged for a
    linker bug report.
  * The GOLD linker has improved warning messages for relocations that
    refer to discarded sections.
- Remove binutils-2.31-branch.diff.gz, fix-pr23919-1.diff,
  fix-pr23919-2.diff, fix-pr23919-3.diff,
  gold-depend-on-opcodes.diff and s390-relro.diff.
- Refresh binutils-skip-rpaths.patch, s390-biarch.diff, cross-avr-size.patch
  and binutils-revert-plt32-in-branches.diff.
* Thu Jan 24 2019 matz@suse.com
- Add s390-relro.diff to improve relro support on s390
  [fate#326356]
* Thu Dec  6 2018 matz@suse.com
- Fix the fix for PR23919 [bsc#1118644]:
  rename handle-ELF-compressed-header-alignment-correctly-by-.patch
  to fix-pr23919-1.diff and add fix-pr23919-2.diff
  and fix-pr23919-3.diff .
* Tue Nov 27 2018 Martin Liška <mliska@suse.cz>
- Add handle-ELF-compressed-header-alignment-correctly-by-.patch:
  PR23919.
* Tue Aug 28 2018 matz@suse.com
- Update to binutils-2_31-branch @e51abf7e3, minor bugfixes in
  the support for the X86_ISA_1_* notes.  Adds
  patch binutils-2.31-branch.diff.gz .
- Add binutils-revert-plt32-in-branches.diff on anything older
  than Tumbleweed to not break old tools not expecting
  PLT32 instead of PC32 relocs on x86_64.
- Includes fixes for these CVEs:
  * from 2.30:
    bnc#1065643 aka CVE-2017-15996 aka PR22361
    bnc#1065689 aka CVE-2017-15939 aka PR22205
    bnc#1065693 aka CVE-2017-15938 aka PR22209
    bnc#1068640 aka CVE-2017-16826 aka PR22376
    bnc#1068643 aka CVE-2017-16832 aka PR22373
    bnc#1068887 aka CVE-2017-16831 aka PR22385
    bnc#1068888 aka CVE-2017-16830 aka PR22384
    bnc#1068950 aka CVE-2017-16829 aka PR22307
    bnc#1069176 aka CVE-2017-16828 aka PR22386
    bnc#1069202 aka CVE-2017-16827 aka PR22306
  * from 2.31:
    bnc#1077745 aka CVE-2018-6323  aka PR22746
    bnc#1079103 aka CVE-2018-6543  aka PR22769
    bnc#1079741 aka CVE-2018-6759  aka PR22794
    bnc#1080556 aka CVE-2018-6872  aka PR22788
    bnc#1081527 aka CVE-2018-7208  aka PR22741
    bnc#1083528 aka CVE-2018-7570  aka PR22881
    bnc#1083532 aka CVE-2018-7569  aka PR22895
    bnc#1086608 aka CVE-2018-8945  aka PR22809
    bnc#1086784 aka CVE-2018-7643  aka PR22905
    bnc#1086786 aka CVE-2018-7642  aka PR22887
    bnc#1086788 aka CVE-2018-7568  aka PR22894
    bnc#1090997 aka CVE-2018-10373 aka PR23065
    bnc#1091015 aka CVE-2018-10372 aka PR23064
    bnc#1091365 aka CVE-2018-10535 aka PR23113
    bnc#1091368 aka CVE-2018-10534 aka PR23110
- Removes binutils-fix-pr21964.diff as it's included in 2.31.
  Rebase testsuite.diff and aarch64-common-pagesize.patch .
* Tue Jul 31 2018 rguenther@suse.com
- Disable -z separate-code everywhere but in Tumbleweed.
* Mon Jul 16 2018 rguenther@suse.com
- Update to binutils 2.31
  * The AArch64 port now supports showing disassembly notes which are emitted
    when inconsistencies are found with the instruction that may result in the
    instruction being invalid.  These can be turned on with the option -M notes
    to objdump.
  * The AArch64 port now emits warnings when a combination of an instruction and
    a named register could be invalid.
  * Added O modifier to ar to display member offsets inside an archive
  * The ADR and ADRL pseudo-instructions supported by the ARM assembler
    now only set the bottom bit of the address of thumb function symbols
    if the -mthumb-interwork command line option is active.
  * Add --generate-missing-build-notes=[yes|no] option to create (or not) GNU
    Build Attribute notes if none are present in the input sources.  Add a
  - -enable-generate-build-notes=[yes|no] configure time option to set the
    default behaviour.  Set the default if the configure option is not used
    to "no".
  * Remove -mold-gcc command-line option for x86 targets.
  * Add -O[2|s] command-line options to x86 assembler to enable alternate
    shorter instruction encoding.
  * Add support for .nops directive.  It is currently supported only for
    x86 targets.
  * Speed up direct linking with DLLs for Cygwin and Mingw targets.
  * Add a configure option --enable-separate-code to decide whether
  - z separate-code should be enabled in ELF linker by default.  Default
    to yes for Linux/x86 targets.  Note that -z separate-code can increase
    disk and memory size.
  * Includes riscv-relax-size.patch, riscv-relax-relocatable.patch,
    riscv-relax-versioned-hidden.patch and riscv-wrap-relax.patch
- Refresh enable-targets-gold.diff.
- Adjust cross-avr-omit_section_dynsym.patch.
- Remove binutils-2.30-branch.diff.
* Mon Jun  4 2018 schwab@suse.de
- riscv-relax-versioned-hidden.patch: RISC-V: Fix symbol address problem
  with versioned symbols (PR ld/22756)
* Sat May 12 2018 afaerber@suse.de
- Restore riscv64-elf cross prefix via symlinks
* Tue Apr  3 2018 matz@suse.com
- Fix pacemaker libqb problem with section start/stop
  symbols, aka PR21964.  [bnc#1075418]
  Adds binutils-fix-pr21964.diff .
  (this is a change from SLE12, that was already included in 2.31
  binutils tree, mentioned for completeness to not loose tracking)
* Thu Mar 22 2018 schwab@suse.de
- riscv-relax-relocatable.patch: RISC-V: Don't enable relaxation in
  relocatable link
* Tue Mar 20 2018 rguenther@suse.com
- Update binutils-2.30-branch.diff: 2.30 branch @7c78c26eefbb8
  * Includes more complete fix for PR20882.
  * Includes fix for PR22836.  [boo#1085784]
  * Includes fix for PR22983.
* Thu Mar  8 2018 schwab@suse.de
- riscv-relax-size.patch: Fix symbol size bug when relaxation deletes bytes
* Tue Mar  6 2018 matz@suse.com
- Add binutils-pr22868.diff to fix testsuite fails in LLVM.
* Mon Feb 26 2018 schwab@suse.de
- Update to binutils 2.30
  * Add --debug-dump=links option to readelf and --dwarf=links option to objdump
    which displays the contents of any .gnu_debuglink or .gnu_debugaltlink
    sections.
    Add a --debug-dump=follow-links option to readelf and a --dwarf=follow-links
    option to objdump which causes indirect links into separate debug info files
    to be followed when dumping other DWARF sections.
  * Add support for loaction views in DWARF debug line information.
  * Add -z separate-code to generate separate code PT_LOAD segment.
  * Add "-z undefs" command line option as the inverse of the "-z defs" option.
  * Add -z globalaudit command line option to force audit libraries to be run
    for every dynamic object loaded by an executable - provided that the loader
    supports this functionality.
  * Tighten linker script grammar around file name specifiers to prevent the use
    of SORT_BY_ALIGNMENT and SORT_BY_INIT_PRIORITY on filenames.  These would
    previously be accepted but had no effect.
  * The EXCLUDE_FILE directive can now be placed within any SORT_* directive
    within input section lists.
- binutils-2.30-branch.diff: 2.30 branch @4cd0043413
- riscv-wrap-relax.patch: Fix linker relaxation with --wrap
- Remove use-hashtype-both-by-default.diff, use
  - -enable-default-hash-style=both instead
- Remove binutils-2.29-branch.diff, s390x-8fe09d7.diff
- Use riscv64-suse-linux as target for cross-riscv64-binutils
* Fri Jan 26 2018 dimstar@opensuse.org
- Drop bc BuildRequires: no longer needed.
* Mon Jan 22 2018 schwab@suse.de
- Add riscv64 to %%target_list
* Wed Jan 17 2018 afaerber@suse.de
- Add arm-none-eabi symlinks (bsc#1074741)
* Mon Oct  2 2017 matz@suse.com
- Add s390x-8fe09d7.diff to fix typo in ELF notes.
* Fri Sep 29 2017 mliska@suse.cz
- Update binutils-2.29-branch.diff to @a45d8fd5ffbf888 fixing PR 22220.
* Thu Sep 28 2017 rguenther@suse.com
- Update to 2.29.1 release, accumulating bugfixes.
- Update binutils-2.29-branch.diff to @a38a1d80 and to be
  relative to the 2.29.1 release fixing following PRs/bnc/CVE:
  22058 [bnc#1057149, CVE-2017-14130]
  21813 [bnc#1052503, CVE-2017-12456, bnc#1052507, CVE-2017-12454,
    bnc#1052509, CVE-2017-12453, bnc#1052511, CVE-2017-12452,
    bnc#1052514, CVE-2017-12450, bnc#1052503, CVE-2017-12456,
    bnc#1052507, CVE-2017-12454, bnc#1052509, CVE-2017-12453,
    bnc#1052511, CVE-2017-12452, bnc#1052514, CVE-2017-12450]
  22148 [bnc#1060599, CVE-2017-14745]
  22163 [bnc#1061241, CVE-2017-14974]
  21933 [bnc#1053347, CVE-2017-12799]
  21787 [bnc#1052518, CVE-2017-12448]
  22018 [bnc#1056312, CVE-2017-13757]
  22170 [bnc#1060621, CVE-2017-14729]
  22047 [bnc#1057144, CVE-2017-14129]
  22059 [bnc#1057139, CVE-2017-14128]
  21990 [bnc#1058480, CVE-2017-14333]
  22113 [bnc#1059050, CVE-2017-14529]
  as well as these PRs:
  22061, 21786, 21916, 21994, 22064, 21995, 21909, 21441, 22060,
  22067, 22032, 21820, 22048, 22199, 21781, 21824, 21861, 22150.
* Wed Aug 30 2017 matz@suse.com
- Update to 2.29 (@5d25156), upstream fix for PR21884, as
  well as PRs 18808 18841 21840 21988 21910 21962 21964.
* Fri Aug 11 2017 matz@suse.com
- Last fixes for PR21884 weren't complete, adjust
  binutils-2.29-branch.diff some more for this.
* Thu Aug 10 2017 matz@suse.com
- Update to 2.29 branch (@de44148c), fixing PR21884, a segfault
  in ld while building memtest86+ .
  Changes binutils-2.29-branch.diff.
* Mon Jul 31 2017 matz@suse.com
- Update to 2.29 branch, fixing PR21847, affecting the ppc64le
  ABI in corner cases since 2.29 release.
  Adds binutils-2.29-branch.diff.
- Remove binutils-2.29-gold-mips.patch, obsolete by the update.
* Wed Jul 26 2017 rguenther@suse.com
- Add binutils-2.29-gold-mips.patch to fix build on SLE-11.
* Wed Jul 26 2017 rguenther@suse.com
- Update to binutils 2.29. [fate#321454, fate#321494, fate#323293]
- Fixes these security-related PRs/bnc/CVEs:
  18750 [bsc#1030296, CVE-2014-9939]
  20891 [bsc#1030585, CVE-2017-7225]
  20892 [bsc#1030588, CVE-2017-7224]
  20898 [bsc#1030589, CVE-2017-7223]
  20905 [bsc#1030584, CVE-2017-7226]
  20908 [bsc#1031644, CVE-2017-7299]
  20909 [bsc#1031656, CVE-2017-7300]
  20921 [bsc#1031595, CVE-2017-7302]
  20922 [bsc#1031593, CVE-2017-7303]
  20924 [bsc#1031638, CVE-2017-7301]
  20931 [bsc#1031590, CVE-2017-7304]
  21409 [bsc#1037052, CVE-2017-8392]
  21412 [bsc#1037057, CVE-2017-8393]
  21414 [bsc#1037061, CVE-2017-8394]
  21432 [bsc#1037066, CVE-2017-8396]
  21440 [bsc#1037273, CVE-2017-8421]
  21580 [bsc#1044891, CVE-2017-9746]
  21581 [bsc#1044897, CVE-2017-9747]
  21582 [bsc#1044901, CVE-2017-9748]
  21587 [bsc#1044909, CVE-2017-9750]
  21594 [bsc#1044925, CVE-2017-9755]
  21595 [bsc#1044927, CVE-2017-9756]
- Feature changes:
  * The MIPS port now supports microMIPS eXtended Physical Addressing (XPA)
    instructions for assembly and disassembly.
  * The MIPS port now supports the microMIPS Release 5 ISA for assembly and
    disassembly.
  * The MIPS port now supports the Imagination interAptiv MR2 processor,
    which implements the MIPS32r3 ISA, the MIPS16e2 ASE as well as a couple
    of implementation-specific regular MIPS and MIPS16e2 ASE instructions.
  * The SPARC port now supports the SPARC M8 processor, which implements the
    Oracle SPARC Architecture 2017.
  * The MIPS port now supports the MIPS16e2 ASE for assembly and disassembly.
  * Add support for ELF SHF_GNU_MBIND and PT_GNU_MBIND_XXX.
  * Add support for the wasm32 ELF conversion of the WebAssembly file format.
  * Add --inlines option to objdump, which extends the --line-numbers option
    so that inlined functions will display their nesting information.
  * Add --merge-notes options to objcopy to reduce the size of notes in
    a binary file by merging and deleting redundant notes.
  * Add support for locating separate debug info files using the build-id
    method, where the separate file has a name based upon the build-id of
    the original file.
  GAS
  * Add support for ELF SHF_GNU_MBIND.
  * Add support for the WebAssembly file format and wasm32 ELF conversion.
  * PowerPC gas now checks that the correct register class is used in
    instructions.  For instance, "addi %%f4,%%cr3,%%r31" warns three times
    that the registers are invalid.
  * Add support for the Texas Instruments PRU processor.
  * Support for the ARMv8-R architecture and Cortex-R52 processor has been
    added to the ARM port.
  GNU ld
  * Support for -z shstk in the x86 ELF linker to generate
    GNU_PROPERTY_X86_FEATURE_1_SHSTK in ELF GNU program properties.
  * Add support for GNU_PROPERTY_X86_FEATURE_1_SHSTK in ELF GNU program
    properties in the x86 ELF linker.
  * Add support for GNU_PROPERTY_X86_FEATURE_1_IBT in ELF GNU program
    properties in the x86 ELF linker.
  * Support for -z ibtplt in the x86 ELF linker to generate IBT-enabled
    PLT.
  * Support for -z ibt in the x86 ELF linker to generate IBT-enabled
    PLT as well as GNU_PROPERTY_X86_FEATURE_1_IBT in ELF GNU program
    properties.
  * Add support for ELF SHF_GNU_MBIND and PT_GNU_MBIND_XXX.
  * Add support for ELF GNU program properties.
  * Add support for the Texas Instruments PRU processor.
  * When configuring for arc*-*-linux* targets the default linker emulation will
    change if --with-cpu=nps400 is used at configure time.
  * Improve assignment of LMAs to orphan sections in some edge cases where a
    mixture of both AT>LMA_REGION and AT(LMA) are used.
  * Orphan sections placed after an empty section that has an AT(LMA) will now
    take an load memory address starting from LMA.
  * Section groups can now be resolved (the group deleted and the group members
    placed like normal sections) at partial link time either using the new
    linker option --force-group-allocation or by placing FORCE_GROUP_ALLOCATION
    into the linker script.
- Includes binutils-bso21193.diff, binutils-bso21333.diff and
  fix-security-bugs.diff.
- Remove ld-dtags.diff, instead configure with --enable-new-dtags.
- Refresh binutils-build-as-needed.diff.
- Remove binutils-2.28-branch.diff.
* Wed Apr  5 2017 afaerber@suse.de
- Add riscv64 target, tested with gcc7 and downstream newlib 2.4.0
  * Prepare riscv32 target (gh#riscv/riscv-newlib#8)
* Fri Mar 31 2017 rguenther@suse.com
- Update binutils-2.28-branch.diff.
- Make compressed debug section handling explicit, disable for
  old products and enable for gas on all architectures otherwise.
- Add binutils-bso21333.diff.  [boo#1029995]
* Thu Mar 30 2017 rguenther@suse.com
- Remove empty rpath component removal optimization from
  binutils-skip-rpaths.patch to workaround CMake rpath handling.
  [boo#1025282]
* Fri Mar 17 2017 matz@suse.com
- Add fix-security-bugs.diff to fix bnc#1029907, bnc#1029908,
  bnc#1029909 and more.  Upstream bugs fixed:
  PR 21135 [bsc#1030298, CVE-2017-7209],
  PR 21137 [bsc#1029909, CVE-2017-6965],
  PR 21139 [bsc#1029908, CVE-2017-6966],
  PR 21156 [bsc#1029907, CVE-2017-6969],
  PR 21157 [bsc#1030297, CVE-2017-7210],
  PR 21147, PR 21148, PR 21149, PR 21150, PR 21151, PR 21155,
  PR 21158, PR 21159
* Wed Mar  8 2017 rguenther@suse.com
- Update to binutils 2.28.
  * Add support for locating separate debug info files using the build-id
    method, where the separate file has a name based upon the build-id of
    the original file.
  * This version of binutils fixes a problem with PowerPC VLE 16A and 16D
    relocations which were functionally swapped, for example,
    R_PPC_VLE_HA16A performed like R_PPC_VLE_HA16D while R_PPC_VLE_HA16D
    performed like R_PPC_VLE_HA16A.  This could have been fixed by
    renumbering relocations, which would keep object files created by an
    older version of gas compatible with a newer ld.  However, that would
    require an ABI update, affecting other assemblers and linkers that
    create and process the relocations correctly.  It is recommended that
    all VLE object files be recompiled, but ld can modify the relocations
    if --vle-reloc-fixup is passed to ld.  If the new ld command line
    option is not used, ld will ld warn on finding relocations inconsistent
    with the instructions being relocated.
  * The nm program has a new command line option (--with-version-strings)
    which will display a symbol's version information, if any, after the
    symbol's name.
  * The ARC port of objdump now accepts a -M option to specify the extra
    instruction class(es) that should be disassembled.
  * The --remove-section option for objcopy and strip now accepts section
    patterns starting with an exclamation point to indicate a non-matching
    section.  A non-matching section is removed from the set of sections
    matched by an earlier --remove-section pattern.
  * The --only-section option for objcopy now accepts section patterns
    starting with an exclamation point to indicate a non-matching section.
    A non-matching section is removed from the set of sections matched by
    an earlier --only-section pattern.
  * New --remove-relocations=SECTIONPATTERN option for objcopy and strip.
    This option can be used to remove sections containing relocations.
    The SECTIONPATTERN is the section to which the relocations apply, not
    the relocation section itself.
  GAS
  * Add support for the RISC-V architecture.
  * Add support for the ARM Cortex-M23 and Cortex-M33 processors.
  GNU ld
  * The EXCLUDE_FILE linker script construct can now be applied outside of the
    section list in order for the exclusions to apply over all input sections
    in the list.
  * Add support for the RISC-V architecture.
  * The command line option --no-eh-frame-hdr can now be used in ELF based
    linkers to disable the automatic generation of .eh_frame_hdr sections.
  * Add --in-implib=<infile> to the ARM linker to enable specifying a set of
    Secure Gateway veneers that must exist in the output import library
    specified by --out-implib=<outfile> and the address they must have.
    As such, --in-implib is only supported in combination with --cmse-implib.
  * Extended the --out-implib=<file> option, previously restricted to x86 PE
    targets, to any ELF based target.  This allows the generation of an import
    library for an ELF executable, which can then be used by another application
    to link against the executable.
  GOLD
  * Add -z bndplt option (x86-64 only) to support Intel MPX.
  * Add --orphan-handling option.
  * Add --stub-group-multi option (PowerPC only).
  * Add --target1-rel, --target1-abs, --target2 options (Arm only).
  * Add -z stack-size option.
  * Add --be8 option (Arm only).
  * Add HIDDEN support in linker scripts.
  * Add SORT_BY_INIT_PRIORITY support in linker scripts.
- Add binutils-2.28-branch.diff.
- Remove binutils-2.27-branch.diff
- Remove binutils-2.27-fix-section-order.diff,
  refine_.cfi_sections_check_to_only_consider_compact_eh_frame.patch
  and aarch64-alignment-frags.patch now upstream.
* Mon Mar  6 2017 schwab@linux-m68k.org
- Configure with --with-system-zlib
* Fri Feb 24 2017 rguenther@suse.com
- Add binutils-bso21193.diff to fix section alignment on
  .gnu_debuglink.  [bso#21193]
* Tue Feb  7 2017 rguenther@suse.com
- Add s390x to gold_archs.
* Mon Feb  6 2017 afaerber@suse.de
- Fix alignment frags for aarch64 (boo#1003846)
  aarch64-alignment-frags.patch
* Sun Dec 18 2016 jengelh@inai.de
- Call ldconfig for libbfd
* Wed Nov 30 2016 idonmez@suse.com
- Add refine_.cfi_sections_check_to_only_consider_compact_eh_frame.patch
  from upstream to fix an assembler problem with clang on ARM.
  Fixes https://sourceware.org/bugzilla/show_bug.cgi?id=20648
* Mon Nov 28 2016 rguenther@suse.com
- Update binutils-2.27-branch.diff to include recent fixes from the branch.
- Add binutils-2.27-fix-section-order.diff to restore monotonically
  increasing section offsets.
* Tue Oct  4 2016 stefan.bruens@rwth-aachen.de
- Remove qemu workaround from spec file, since qemu 2.5.0rc0 the
  length of the argument list is no longer limited to 128 kByte.
* Wed Aug 24 2016 rguenther@suse.com
- Update to binutils 2.27.
  * Add a configure option, --enable-64-bit-archive, to force use of a
    64-bit format when creating an archive symbol index.
  * Add --elf-stt-common= option to objcopy for ELF targets to control
    whether to convert common symbols to the STT_COMMON type.
  GAS:
  * Default to --enable-compressed-debug-sections=gas for Linux/x86 targets.
  * Add --no-pad-sections to stop the assembler from padding the end of output
    sections up to their alignment boundary.
  * Support for the ARMv8-M architecture has been added to the ARM port.
    Support for the ARMv8-M Security and DSP Extensions has also been added
    to the ARM port.
  * ARC backend accepts .extInstruction, .extCondCode, .extAuxRegister, and
    .extCoreRegister pseudo-ops that allow an user to define custom
    instructions, conditional codes, auxiliary and core registers.
  * Add a configure option --enable-elf-stt-common to decide whether ELF
    assembler should generate common symbols with the STT_COMMON type by
    default.  Default to no.
  * New command line option --elf-stt-common= for ELF targets to control
    whether to generate common symbols with the STT_COMMON type.
  * Add ability to set section flags and types via numeric values for ELF
    based targets.
  * Add a configure option --enable-x86-relax-relocations to decide whether
    x86 assembler should generate relax relocations by default.  Default to
    yes, except for x86 Solaris targets older than Solaris 12.
  * New command line option -mrelax-relocations= for x86 target to control
    whether to generate relax relocations.
  * New command line option -mfence-as-lock-add=yes for x86 target to encode
    lfence, mfence and sfence as "lock addl $0x0, (%%[re]sp)".
  * Add assembly-time relaxation option for ARC cpus.
  * Add --with-cpu=TYPE configure option for ARC gas.  This allows the default
    cpu type to be adjusted at configure time.
  GOLD:
  * Add a configure option --enable-relro to decide whether -z relro should
    be enabled by default.  Default to yes.
  * Add support for s390, MIPS, AArch64, and TILE-Gx architectures.
  * Add support for STT_GNU_IFUNC symbols.
  * Add support for incremental linking (--incremental).
  GNU ld:
  * Add a configure option --enable-relro to decide whether -z relro should
    be enabled in ELF linker by default.  Default to yes for all Linux
    targets except FRV, HPPA, IA64 and MIPS.
  * Support for -z noreloc-overflow in the x86-64 ELF linker to disable
    relocation overflow check.
  * Add -z common/-z nocommon options for ELF targets to control whether to
    convert common symbols to the STT_COMMON type during a relocatable link.
  * Support for -z nodynamic-undefined-weak in the x86 ELF linker, which
    avoids dynamic relocations against undefined weak symbols in executable.
  * The NOCROSSREFSTO command was added to the linker script language.
  * Add --no-apply-dynamic-relocs to the AArch64 linker to do not apply
    link-time values for dynamic relocations.
- Add binutils-2.27-branch.diff with fixes on the branch sofar.
- Remove gold-relocate-tls.patch, included in binutils 2.27.
* Wed Jul  6 2016 rguenther@suse.com
- Update to binutils 2.26.1.
- Remove binutils-2.26-branch.diff.
* Fri Mar 18 2016 rguenther@suse.com
- Update binutils-2.26-branch.diff, updates to branch head.
  (swo#19807) (bnc#970239)
- Disable -mrelax-relocations by default on old products.
* Wed Mar  9 2016 rguenther@suse.com
- Update binutils-2.26-branch.diff, updates to branch head.
  (swo#19739) (swo#19775)
* Mon Feb 29 2016 rguenther@suse.com
- Add binutils-2.26-branch.diff, updates to branch head.
  * Adds -mrelax-relocations on x86
  * Fixes bso#19698
* Mon Feb  1 2016 rguenther@suse.com
- Refresh cross-avr-nesc-as.patch
* Wed Jan 27 2016 rguenther@suse.com
- Update to binutils 2.26
  * Add --fix-stm32l4xx-629360 to the ARM linker to enable a link-time
    workaround for a bug in the bus matrix / memory controller for some of
    the STM32 Cortex-M4 based products (STM32L4xx)
  * Add a configure option --enable-compressed-debug-sections={all,ld} to
    decide whether DWARF debug sections should be compressed by default.
  * Add support for the ARC EM/HS, and ARC600/700 architectures.
  * Experimental support for linker garbage collection (--gc-sections)
    has been enabled for COFF and PE based targets.
  * New command line option for ELF targets to compress DWARF debug
    sections, --compress-debug-sections=[none|zlib|zlib-gnu|zlib-gabi].
  * New command line option, --orphan-handling=[place|warn|error|discard], to
    adjust how orphan sections are handled.  The default is 'place' which gives
    the current behaviour, 'warn' and 'error' issue a warning or error
    respectively when orphan sections are found, and 'discard' will discard all
    orphan sections.
  * Add support for LLVM plugin.
  * Add --print-memory-usage option to report memory blocks usage.
  * Add --require-defined option, it's like --undefined except the new symbol
    must be defined by the end of the link.
  * Add a configure option --enable-compressed-debug-sections={all,gas} to
    decide whether DWARF debug sections should be compressed by default.
  * Add support for the ARC EM/HS, and ARC600/700 architectures.  Remove
    assembler support for Argonaut RISC architectures.
  * Add option to objcopy to insert new symbols into a file:
  - -add-symbol <name>=[<section>:]<value>[,<flags>]
  * Add support for the ARC EM/HS, and ARC600/700 architectures.
  * Extend objcopy --compress-debug-sections option to support
  - -compress-debug-sections=[none|zlib|zlib-gnu|zlib-gabi] for ELF
    targets.
  * Add --update-section option to objcopy.
  * Add --output-separator option to strings.
- Includes z13 support, remove 0001-S-390-Add-support-for-IBM-z13.patch,
  0002-S-390-Add-check-for-length-field-operand.patch,
  0003-S-390-Add-more-IBM-z13-instructions.patch,
  0004-S-390-Fixes-for-z13-instructions.patch and
  0005-S-390-z13-use-GNU-attribute-to-indicate-vector-ABI.patch
- Includes fixes in binutils-fix--dynamic-list.patch,
  binutils-fix-gold-aarch64.diff, gold-arm64-abi-pagesize.patch
  and s390-troo-insn-type.patch
- Refresh s390-pic-dso.diff and binutils-build-as-needed.diff
* Wed Jan 13 2016 schwab@suse.de
- gold-relocate-tls.patch: Fix internal error when applying TLSDESC
  relocations with no TLS segment
* Wed Oct 14 2015 schwab@suse.de
- s390-troo-insn-type.patch: fix wrong insn type for troo insn
- aarch64-common-pagesize.patch: change default common-page-size to 64K on
  aarch64
* Thu Oct  1 2015 schwab@suse.de
- gold-arm64-abi-pagesize.patch: fix ABI pagesize for aarch64 in gold
* Tue Jul 21 2015 matz@suse.de
- Disable use-hashtype-both-by-default.diff for
  the mips target, it's incompatible with it.  [bnc #938658]
* Mon Jul 13 2015 afaerber@suse.de
- Add cross-rx-binutils package for Renesas RX
* Fri Jul 10 2015 schwab@linux-m68k.org
- Work around qemu bug
* Thu Jul  9 2015 matz@suse.de
- Update to 2.25 branch at 2f5b97b4f (changes
  binutils-2.25-branch.diff.gz) fixes PR 18481, gas/18541.
- Add patches for s390 z13 support (backports from
  to-be 2.26):
  0001-S-390-Add-support-for-IBM-z13.patch
  0002-S-390-Add-check-for-length-field-operand.patch
  0003-S-390-Add-more-IBM-z13-instructions.patch
  0004-S-390-Fixes-for-z13-instructions.patch
  0005-S-390-z13-use-GNU-attribute-to-indicate-vector-ABI.patch .
* Tue Jul  7 2015 afaerber@suse.de
- Fix %%TARGET vs. $TARGET_OS inconsistencies by turning $TARGET_OS
  into %%TARGET_OS for reuse in install and file sections.
  This fixes the assumption that $TARGET_OS will match %%{TARGET}*.
* Wed Jun 10 2015 dmueller@suse.com
- enable gold for aarch64
* Mon May 18 2015 matz@suse.de
- Move sed call from %%prep to %%build to not disturb quilt.
- Add binutils-2.25-branch.diff.gz:
  Update to 2.25 branch at 8fe8994c, fixing many bugs:
  PR ld/15228, binutils/17512, 17165, binutils/17531, ld/17615, 17666,
  ld/17709, gas/17753, 17755, 17817, ld/17827, 17842, binutils/17926,
  17954, 18010, ld/18167, ld/18222, ld/18270.
- Remove eh-frame-hdr-on-shared-lib-bfd.patch: Included already.
- Remove gold-opd-visibility.patch: Included already.
* Mon May 18 2015 meissner@suse.com
- move info deinstall to preun section
* Sat May 16 2015 hrvoje.senjan@gmail.com
- Added binutils-fix--dynamic-list.patch:
  Fixes https://sourceware.org/bugzilla/show_bug.cgi?id=13577 and
  https://sourceware.org/bugzilla/show_bug.cgi?id=16992
* Thu Feb 19 2015 schwab@suse.de
- gold-opd-visibility.patch: Set default visibility on discarded .opd
  symbols
* Wed Jan 21 2015 schwab@suse.de
- eh-frame-hdr-on-shared-lib-bfd.patch: Don't create .eh_frame_hdr on
  shared lib bfd, fixes building libgcj on ppc64
* Thu Jan 15 2015 rguenther@suse.com
- Update to binutils 2.25 release.
  * Add --data option to strings to only print strings in loadable, initialized
    data sections.  Change the default behaviour to be --all, but add a new
    configure time option of --disable-default-strings-all to restore the old
    default behaviour.
  * Add --include-all-whitespace to strings.
  * Add --dump-section option to objcopy.
  * Add support for the Andes NDS32.
  * PE binaries now once again contain real timestamps by default.  To disable
    the inclusion of a timestamp in a PE binary, use the --no-insert-timestamp
    command line option.
  * Replace support for openrisc and or32 with support for or1k.
  * Add support for the --build-id command line option to COFF based targets.
  * x86/x86_64 pe-coff now supports the --build-id option.
  * Add support for the AVR Tiny microcontrollers.
  * Enhanced the ARM port to accept the assembler output from the CodeComposer
    Studio tool.  Support is enabled via the new command line option -mccs.
- Update to 2.25 branch head.
  * Pulls PIE fixes.
* Mon Jan 12 2015 dimstar@opensuse.org
- Minor fix on the usage of update-alternatives
  https://en.opensuse.org/openSUSE:Packaging_Multiple_Version_guidelines
* Mon Dec  1 2014 matz@suse.de
- Update to current 2.25 pre-release branch, at 127a4644.
- binutils-fix-gold-aarch64.diff: fixing build temporarily broken
  on brach.
- Remove obsolete patches: binutils-2.24-branch.diff.gz,
  pie-m68k.patch, binutils-2.24-auto-plugin.diff, ld-testsuite.patch,
  binutils-2.24-bso16746.diff .
* Fri Oct 31 2014 afaerber@suse.de
- Enable Adapteva Epiphany target
* Tue May  6 2014 rguenther@suse.com
- binutils-2.24-bso16746.diff: Fix bso#16746, spurious warnings
  for warn annotated symbols with LTO.
* Sun Apr  6 2014 schwab@linux-m68k.org
- ld-dtags.diff: update testsuite for --enable-new-dtags default
- ld-testsuite.patch: fix spurious failures in ld-plugin/lto.exp
* Thu Apr  3 2014 rguenther@suse.com
- binutils-2.24-auto-plugin.diff: Update from git commit that went
  to trunk.
* Wed Mar 26 2014 matz@suse.de
- Update to current 2.24 branch at 25f1c421:
  AVX512 fixes, new x86 instructions clflushopt, xsaves, xsavec, xrstors.
  aarch64: linker fixes for PLT stubs, correct float const 0.0 parsing,
  support ifunc in static links.
  Fix ld/16643 (problem with GCed sections).
  powerpc64le: fix ld segfault with --emit-relocs.
  Fix buffer underrun in x86 disassembler.
  Fix merging of skipped weak symbols.  [bnc #863764]
* Mon Mar 24 2014 rguenther@suse.com
- Add binutils-2.24-auto-plugin.diff to make plugin auto-load work
  for GCC LTO objects.  [bso#14698]
* Fri Feb 21 2014 matz@suse.de
- Disable --enable-deterministic-archives again, as it breaks
  valid Makefiles.
* Mon Feb 10 2014 subchaser1@gmail.com
- cross-avr-size.patch: AVR-style output in avr-size utility
* Mon Jan 27 2014 crrodriguez@opensuse.org
- build with --enable-deterministic-archives so ar and ranlib
  cooperate in the creation of reproducible builds.
* Mon Dec  9 2013 matz@suse.de
- Update to 2.24 release and to branch at 9177510e:
  * Add support for the Texas Instruments MSP430X processor.
  * Add support for Altera Nios II.
  * Add support for the V850E3V5 architecture.
  * Add support for the Imagination Technologies Meta processor.
  * --enable-new-dtags no longer generates old dtags in addition to new dtags.
  * Remove assembler and linker support for MIPS ECOFF targets.
  * Remove assembler support for MIPS ECOFF targets.
  * Add ALIGN_WITH_INPUT to the linker script language to force the
    alignment of an output section to use the maximum alignment of
    all its input sections.
  * Add -gdwarf-sections command line option to enable per-code-section
    generation of DWARF .debug_line sections.
  * Objcopy now supports wildcard characters in command line options that take
    section names.
* Fri Nov 29 2013 matz@suse.de
- Update to 2.23.92 prerelease, mostly for ppc64le support.
- Add cross-ppc64le-binutils.
* Mon Oct 28 2013 schwab@suse.de
- Add cross-m68k-binutils
* Wed Oct  9 2013 schwab@suse.de
- pie-m68k.patch: Emit DT_DEBUG also for PIE
* Fri Sep 20 2013 matz@suse.de
- Update to 2.23.90 prerelease, remove patches that
  are upstream ( aarch64-biarch.patch, aarch64-dynamic-placement.patch,
  aarch64-execstack.patch, aarch64-gc-section-support.patch,
  aarch64-support-1796bf893c4729d5c523502318d72cae78495d6c.diff,
  aarch64-support-f426901e1be0f58fe4e9386cada50ca57d0a4f36.diff,
  binutils-2.22-objalloc.patch,
  binutils-2.23.52.0.1-64-bit-thin-archives.patch,
  s390-machinemode.patch, warning-symbol-sections.patch).
* Sat Aug 31 2013 idonmez@suse.com
- Add binutils-2.23.52.0.1-64-bit-thin-archives.patch to fix thin
  archive creation on 64bit systems. This is rh#915411 and should
  also fix webkitgtk on s390x.
* Mon Jul 29 2013 schwab@suse.de
- warning-symbol-sections.patch: correct test in last change
* Mon Jul 22 2013 schwab@suse.de
- warning-symbol-sections.patch: don't clobber warning sections from
  shared libraries
* Mon Jul  1 2013 schwab@suse.de
- aarch64-dynamic-placement.patch: Correct placement of &_DYNAMIC
* Wed Jun 26 2013 dmueller@suse.com
- add armv6l to target list
* Tue Jun 11 2013 dmueller@suse.com
- add aarch64-support-1796bf893c4729d5c523502318d72cae78495d6c.diff
- add aarch64-support-f426901e1be0f58fe4e9386cada50ca57d0a4f36.diff
* Wed May 15 2013 rguenther@suse.com
- Drop cross-alpha-binutils.  Adjust pre-checkin.sh to remove
  all cross packages before re-generating them.
* Tue May 14 2013 schwab@suse.de
- Tell bfd ELF backend that aarch64 defaults to non-exec stack
* Wed Apr  3 2013 rguenther@suse.com
- Re-instantiate patch to warn about non-PIC code in shared objects
  on s390x.
* Thu Mar 28 2013 rguenther@suse.com
- Update to binutils 2.23.2.
  * various bugfixes
- Refresh no longer applying patch.
* Tue Mar  5 2013 schwab@suse.de
- Add aarch64 support for --gc-sections
  (from http://sourceware.org/ml/binutils/2013-02/msg00285.html)
* Wed Dec 19 2012 schwab@suse.de
- Backport s390 .machinemode pseudo insn
* Fri Nov 30 2012 rguenther@suse.com
- Revert upstream change to error on bfd.h usage without first
  including some config.h
* Wed Nov 28 2012 rguenther@suse.com
- Change update-alternative priorities to always prefer GNU ld
* Tue Nov 27 2012 jengelh@inai.de
- Implement update-alternatives service for gold
* Tue Nov 27 2012 adrian@suse.de
- update to version 2.23.1 release
- add aarch64 biarch patch
* Sat Nov 24 2012 adrian@suse.de
- add cross-aarch64-binutils
* Thu Nov 22 2012 jengelh@inai.de
- Have pre_checkin.sh create cross-sparc64-binutils
* Wed Oct 24 2012 rguenther@suse.com
- Update to binutils 2.23 branch head.
  * Includes binutils 2.23 release.
* Mon Sep 17 2012 rguenther@suse.com
- Update to binutils 2.23 release candidate.
- Remove no longer applying AVR patch.
* Fri Sep  7 2012 coolo@suse.com
- add makeinfo as explicit buildrequire
* Mon Sep  3 2012 idonmez@suse.com
- Enable threaded linking in gold.
* Mon Sep  3 2012 rguenther@suse.com
- Add patch to fix libiberty integer overflow.  [bnc#776968]
* Thu Jun 21 2012 adrian@suse.de
- fix default elf format for arm cross tools
* Tue Jun 19 2012 factory-maintainer@kulow.org
- fix stupid typo
* Mon Jun 18 2012 coolo@suse.com
- the previous fix was not good enough, another iteration of the same
* Thu Jun 14 2012 coolo@suse.com
- exclude our target arch for cross compiling - this is just not cross
* Thu Apr 19 2012 rguenther@suse.com
- Consistently use $target-suse-linux triplets.
* Wed Feb 15 2012 rguenther@suse.com
- Drop the new spec files again, instead move the cross-$arch-binutils
  contents to /usr, away from /opt.
* Tue Feb 14 2012 max@suse.com
- Add spec files that build variants for arm and avr that install
  under /usr rather than /opt/cross.
- Add avr-binutils-relocs.patch to fix a crash in avr-ld.
  http://sourceware.org/bugzilla/show_bug.cgi?id=12161
* Thu Jan 26 2012 rguenther@suse.com
- Fix package licenses to follow SPDX format, adjust to reality.
* Wed Jan 25 2012 rguenther@suse.com
- Amend patch to fix arm unwind table corruption.  [bso#13449]
* Wed Jan  4 2012 rguenther@suse.com
- Add patch to fix arm unwind table corruption.  [bso#13449]
- Canonicalize arm targets.
- Enable gold for arm.
* Tue Jan  3 2012 rguenther@suse.com
- Add patch to fix build-id issues.  [bso#12451]
* Tue Dec  6 2011 rguenther@suse.com
- Update to final binutils 2.22 release.
* Wed Nov  2 2011 rguenther@suse.com
- Update to binutils-2_22-branch head.
  * Adds support for LDPT_GET_SYMBOLS_V2.
  * Drop patches that have been applied upstream.
* Fri Sep 30 2011 tserong@suse.com
- Fix --gc-sections failure with symbol versioning [bso#13195]
* Wed Sep 28 2011 rguenther@suse.com
- Update to binutils-2_22-branch head.
  * Drop patches that have been applied upstream.
  * Drop patches that no longer apply.
* Thu Sep 22 2011 adrian@suse.de
- use -gnueabi extension to switch to new abi for arm
* Thu Sep 22 2011 dmueller@suse.de
- Add support for arm-*-gnueabihf targets (PR ld/12643)
* Wed Sep 21 2011 adrian@suse.de
- add arm targets
* Tue Aug 23 2011 rguenther@novell.com
- Fix XLC object linker complaints.  [bnc#713504]
* Sun Aug 21 2011 aj@suse.de
- Make --no-copy-dt-needed-entries the default for ld.
* Tue Jul 12 2011 rguenther@novell.com
- Add patch for bogus executable stack setting with -flto.  [bso#12982]
* Mon Jul 11 2011 rguenther@novell.com
- BuildRequire glibc-devel-static to fix static linking tests.
* Tue Jul  5 2011 saschpe@suse.de
- Add patch to fix a readelf endless loop bug.  [bso#12855]
* Tue Jun 28 2011 rguenther@novell.com
- Update to binutils 2.21.1 release.
  * Add --interleave-width option to objcopy to allowing copying a range
    of bytes from the input to the output with the --interleave option.
  * Add support for the TMS320C6000 (TI C6X) processor family.
  * Readelf can now display ARM unwind tables (.ARM.exidx / .ARM.extab)
    using the -u / --unwind option.
  * Add --dyn-syms to readelf to dump dynamic symbol table.
  * A new tool - elfedit - has been added to directly manipulate ELF
    format binaries.
  * Add to dlltool .def file feature of aliasing PE internal symbol name
    by '== <ID>' option.
  * Add a new command line option -a / --addresses to addr2line to display
    the address before function name or source filename.
  * Add a new command line option -p / --pretty-print to addr2line to have
    a more human readable output.
  * The hppa/som targets can now be compiled on any host.
- Add dependency to opcodes from gold.
* Fri Jun 17 2011 matz@suse.de
- Add support for x86_64-pep target [needed for Xen fate #311376]
* Thu Jun  9 2011 matz@novell.com
- Add patch to support AMD Bulldozer v2 [fate #312149]
* Tue Jun  7 2011 rguenther@novell.com
- Update to binutils-2_21-branch head.  [bnc#698346]
* Fri May 27 2011 rguenther@novell.com
- Disable cross-sh4-binutils.
* Wed May  4 2011 rguenther@novell.com
- Update to binutils-2_21-branch head.  [bnc#691290]
* Tue Apr 19 2011 rguenther@novell.com
- Update to binutils-2_21-branch head.  [fate#311554] [fate#311972]
* Mon Jan 10 2011 rguenther@novell.com
- Update to binutils 2.21.
  * linker plugin support
  * AMD Bulldozer enablement
- Disable package fail when testsuite failures occur for now
  because of gold (testsuite) issues.
* Tue Jul 27 2010 rguenther@novell.com
- drop cross-avr-binutils
* Tue Jul 27 2010 coolo@novell.com
- split the gold build into 2 make steps to avoid random
  build failures (ugly work around in fact)
* Thu Jul  8 2010 jengelh@medozas.de
- Default to creating ELF64 objects under sparc64
* Mon Jun 28 2010 jengelh@medozas.de
- use %%_smp_mflags
* Mon Apr 12 2010 matz@suse.de
- Initialize memory for MALLOC_PERTURB on ppc.  [PR gas/11486]
  Rewrite history by including this:
    Wed Mar 24 17:23:32 CET 2010 - matz@suse.de
  - Fix testcase breaking with MALLOC_PERTURB.  [bnc #590820]
    Sat Feb 13 17:52:11 CET 2010 - rguenther@suse.de
  - Drop build counter from the libbfd and libopcode SONAMEs.
    Fri Jan 22 15:31:06 CET 2010 - matz@suse.de
  - Update to current binutils-2_20-branch.  [bnc #561142, #573019]
    Wed Jan 13 15:16:44 CET 2010 - matz@novell.com
  - Fix removal of unwanted files (man,info,libiberty) on the
    cross binutils.
    Sat Dec 12 19:09:40 CET 2009 - jengelh@medozas.de
  - add baselibs.conf as a source
    Mon Dec  7 16:14:27 CET 2009 - jengelh@medozas.de
  - SPARC build support for binutils
    Wed Nov  4 15:44:30 CET 2009 - matz@suse.de
  - Copy from SLE11 SP1.  Compared to that add --as-needed by default
    patch again.
    Mon Oct 19 11:15:51 CEST 2009 - rguenther@suse.de
  - Update to binutils 2.20 snapshot.
  * disable patches that no longer apply
  * disable make check handling everywhere
* Fri Apr  9 2010 matz@suse.de
- Fix encoding of LWP instructions, and get rid of 16bit forms.
* Fri Feb 12 2010 matz@suse.de
- Add more aliases for VPCOM* instructions, xsave64, xrstor64,
  and vpermil2p (XOP support).
* Tue Feb  9 2010 matz@suse.de
- Add support for AMD XOP instructions.  [bnc #578249]
* Fri Jan 22 2010 matz@suse.de
- Update to current binutils-2_20-branch.  [bnc #561142, #573019]
* Wed Nov  4 2009 matz@suse.de
- Update to binutils 2.20 branch, remove patches that went upstream.
  Don't activate --as-needed by default for SLE11 SP1.
  [fate #306880, #307034]
  [bnc #546106, #483978]
* Mon Oct 12 2009 rguenther@suse.de
- enable gold plugins, fix build on older distros.
* Wed Oct  7 2009 coolo@novell.com
- obsolete binutils-32bit, it can't be left around
* Mon Aug 24 2009 rguenther@suse.de
- disable gold build before openSUSE 11.0.
* Thu Aug 20 2009 rguenther@suse.de
- add patch to drop .gnu.lto_* sections
* Fri Jun 12 2009 coolo@novell.com
- follow only SUSE_ASNEEDED
* Tue Jun  9 2009 matz@suse.de
- Use --as-needed by default in the build system.
* Wed May 27 2009 rguenther@suse.de
- Update to head of trunk.
- Add patch to fix gold build with glibc 2.10, gcc 4.4.
* Fri Mar 27 2009 rguenther@suse.de
- Update to head of trunk.
- Add zlib-devel-static BuildRequires to fix testsuite.
- Package gold locales.
* Mon Feb 16 2009 schwab@suse.de
- Update to head of trunk.
* Mon Feb 16 2009 rguenther@suse.de
- Update to 2.19.51 snapshot.  Fixes build with GCC 4.4.
* Tue Jan 27 2009 schwab@suse.de
- Update to head of trunk.
* Thu Jan 22 2009 schwab@suse.de
- Adjust list of extra targets.
* Mon Jan 19 2009 schwab@suse.de
- Update to head of trunk.
- Add gold.
* Thu Jan 15 2009 schwab@suse.de
- Use consistent label names.
* Thu Jan 15 2009 olh@suse.de
- remove Requires: binutils-XXbit in binutils-devel-XXbit package
* Fri Jan  9 2009 schwab@suse.de
- Fix last change.
* Fri Jan  9 2009 olh@suse.de
- build binutils and binutils-devel -XXbit packages (bnc#445037)
* Wed Dec 10 2008 olh@suse.de
- use Obsoletes: -XXbit only for ppc64 to help solver during distupgrade
  (bnc#437293)
* Thu Dec  4 2008 schwab@suse.de
- Update symbol visibility checks during linking on s390.
* Wed Dec  3 2008 schwab@suse.de
- Fix corner case during link relaxing.
* Thu Nov 27 2008 schwab@suse.de
- Fix disassembler bug.
- Help some devel users.
* Fri Nov 21 2008 schwab@suse.de
- Import bugfixes from 2.19 branch.
* Wed Nov 19 2008 schwab@suse.de
- Fix handling of DW_CFA_advance_loc* in the assembler.
* Mon Nov 10 2008 schwab@suse.de
- Update last change.
* Fri Nov  7 2008 schwab@suse.de
- Fix crash in strip.
* Thu Nov  6 2008 rguenther@suse.de
- build cross-spu-binutils with a /usr/spu sysroot
* Thu Oct 30 2008 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Mon Oct 20 2008 schwab@suse.de
- Update to binutils 2.19.
  * Added -wL switch to dump decoded contents of .debug_line.
  * Added support for "thin" archives which contain pathnames pointing to
    object files rather than the files themselves and which contain a
    flattened symbol index for all objects, and archives, which have been
    added to the archive.
  * Added -F switch to objdump to include file offsets in the disassembly.
  * Added -c switch to readelf to allow string dumps of archive symbol index.
  * Support for SSE5 has been added to the i386 port.
  * Added -p switch to readelf to allow string dumps of sections.
  * New pseudo op .cfi_val_encoded_addr, to record constant addresses in unwind
    tables without runtime relocation.
  * New command line option, -h-tick-hex, for sh, m32c, and h8/300 targets, which
    adds compatibility with H'00 style hex constants.
  * New command line option, -msse-check=[none|error|warning], for x86
    targets.
  * New sub-option added to the assembler's -a command line switch to
    generate a listing output.  The 'g' sub-option will insert into the listing
    various information about the assembly, such as assembler version, the
    command line options used, and a time stamp.
  * New command line option -msse2avx for x86 target to encode SSE
    instructions with VEX prefix.
  * Add Intel XSAVE, EPT, MOVBE, AES, PCLMUL, AVX/FMA support for x86 target.
  * New command line options, -march=CPU[,+EXTENSION...], -mtune=CPU,
  - mmnemonic=[att|intel], -msyntax=[att|intel], -mindex-reg,
  - mnaked-reg and -mold-gcc, for x86 targets.
  * Support for generating wide character strings has been added via the new
    pseudo ops: .string16, .string32 and .string64.
  * Support for SSE5 has been added to the i386 port.
  * Linker scripts support a new INSERT command that makes it easier to
    augment the default script.
  * Linker script input section filespecs may now specify a file within an
    archive by writing "archive:file".
  * The --sort-common switch now has an optional argument which specifies the
    direction of sorting.
  * The M68K linker now supports multiple GOT generation schemes controlled via
    the --got=<type> command line option.
  * The ARM EABI linker will now generate stubs for function calls to symbols
    that are too far away.  The placement of the stubs is controlled by a new
    linker command line option: --stub-group-size=N.
* Thu Oct  9 2008 schwab@suse.de
- Bug fixes.
* Tue Oct  7 2008 jblunck@suse.de
- bfd-assign_file_positions_for_load_sections-STRIP_NONDEBUG-fix.diff:
  Do not only look at the first section in a segment to decide if it has
  contents or not. This fixes the "section ... can't be allocated in segment"
  errors when using objcopy --only-keep-debug to create the *.debug files.
* Wed Sep 17 2008 schwab@suse.de
- Update to binutils 2.18.91 snapshot.
* Fri Sep 12 2008 schwab@suse.de
- Update to head of 2.19 branch.
* Thu Sep  4 2008 schwab@suse.de
- Update to head of trunk.
* Fri Aug  8 2008 schwab@suse.de
- Update to head of trunk.
* Fri Jul 18 2008 schwab@suse.de
- Update to head of trunk.
* Sun Jul 13 2008 olh@suse.de
- enable targets i386-macos10, powerpc-macos, powerpc-macos10,
  spu-elf unconditionally in binutils
* Fri Jul 11 2008 schwab@suse.de
- Update to head of trunk.
* Wed Jun 18 2008 schwab@suse.de
- Update to head of trunk.
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Wed Apr  9 2008 schwab@suse.de
- Update to head of trunk.
* Tue Mar 25 2008 schwab@suse.de
- Update to head of trunk.
* Fri Mar  7 2008 schwab@suse.de
- Update to head of trunk.
* Mon Feb 25 2008 schwab@suse.de
- Update to head of trunk.
* Fri Feb 15 2008 schwab@suse.de
- Update to head of trunk.
* Sun Feb 10 2008 schwab@suse.de
- Allow R_S390_PC32DBL against protected function symbols.
* Fri Feb  1 2008 schwab@suse.de
- Update to head of trunk.
* Fri Jan 25 2008 schwab@suse.de
- Update to head of trunk.
* Thu Jan 17 2008 schwab@suse.de
- Update to head of trunk.
* Thu Jan 10 2008 schwab@suse.de
- Update to head of trunk.
* Mon Nov 12 2007 schwab@suse.de
- Update to head of trunk.
* Tue Oct  2 2007 schwab@suse.de
- Update to head of trunk.
- Add hppa64 target.
* Mon Sep  3 2007 schwab@suse.de
- Add fix for PR4888.
* Thu Jul 26 2007 schwab@suse.de
- Update to head of trunk.
* Fri Jul 13 2007 schwab@suse.de
- Update to head of trunk.
* Fri Jun 29 2007 schwab@suse.de
- Update to head of trunk.
* Fri Jun 22 2007 schwab@suse.de
- Update to head of trunk.
- Drop Bdirect patches.
* Mon Jun 11 2007 schwab@suse.de
- Update to head of trunk.
* Sat Jun  2 2007 schwab@suse.de
- Allow only static linking of lib{bfd,opcodes} outside binutils.
* Tue May 15 2007 schwab@suse.de
- Update to head of trunk.
* Fri May  4 2007 schwab@suse.de
- Update to binutils CVS HEAD.
- Remove obsolete obsoletes.
* Mon Apr 23 2007 olh@suse.de
- Fix POWER6 floating point disassembling [#266874]
* Thu Apr 12 2007 schwab@suse.de
- Build cross tools with sysroot.
* Thu Apr  5 2007 schwab@suse.de
- Update to binutils CVS HEAD.
- Add spu to the list of cross targets.
* Mon Mar 26 2007 rguenther@suse.de
- Add bison and flex BuildRequires.
* Wed Mar 21 2007 schwab@suse.de
- Update to binutils CVS HEAD.
* Fri Mar 16 2007 schwab@suse.de
- Update to binutils CVS HEAD.
* Sun Feb 25 2007 schwab@suse.de
- Add mips to the list of extra targets.
* Tue Feb 20 2007 schwab@suse.de
- Avoid build failure with interface change.
* Mon Feb 19 2007 schwab@suse.de
- Update to binutils CVS HEAD.
* Tue Feb  6 2007 rguenther@suse.de
- Add sh4 to the list of cross targets.
* Fri Feb  2 2007 schwab@suse.de
- Switch to hashtype=both by default.
* Mon Jan 29 2007 schwab@suse.de
- Update to binutils CVS HEAD.
* Wed Jan 24 2007 jw@suse.de
- fixed memory corruption in ld -m avr2 --oformat ihex a
  sourceware bugzilla#3874
* Tue Jan 23 2007 schwab@suse.de
- Update to binutils CVS HEAD.
* Mon Jan 15 2007 jw@suse.de
- bin/avr-nesc-as symlinked as avr/bin/nesc-as
* Fri Jan 12 2007 jw@suse.de
- Added avr-nesc-as support (rschiele@gmail.com)
* Mon Jan  8 2007 schwab@suse.de
- Update to binutils 2.17.50.0.9.
  1. Update from binutils 2007 0103.
  2. Fix --wrap linker bug.
  3. Improve handling ELF binaries generated by foreign ELF linkers.
  4. Various ELF M68K bug fixes.
  5. Score bug fixes.
  6. Don't read past end of archive elements. PR 3704.
  7. Improve .eh_frame_hdr section handling.
  8. Fix symbol visibility with comdat/linkonce sections in ELF linker.
  PR 3666.
  9. Fix 4 operand instruction handling in x86 assembler.
  10. Properly check the 4th operand in x86 assembler. PR 3712.
  11. Fix .cfi_endproc handling in assembler. PR 3607.
  12. Various ARM bug fixes.
  13. Various PE linker fixes.
  14. Improve x86 dissassembler for cmpxchg8b.
- Split off binutils-devel.
* Mon Dec  4 2006 schwab@suse.de
- Update to binutils 2.17.50.0.8.
  1. Update from binutils 2006 1201.
  2. Fix "objcopy --only-keep-debug" crash. PR 3609.
  3. Fix various ARM ELF bugs.
  4. Fix various xtensa bugs.
  5. Update x86 disassembler.
* Mon Oct 16 2006 schwab@suse.de
- Fix overflow in addend_compare [#209807].
* Fri Oct 13 2006 schwab@suse.de
- Update last change.
* Tue Oct 10 2006 schwab@suse.de
- Fix invalid debug info.
* Fri Oct  6 2006 aj@suse.de
- Improve last patch.
* Fri Oct  6 2006 aj@suse.de
- Fix PR210331 (wrong size of empty loadable sections).
* Thu Sep 28 2006 schwab@suse.de
- Update to binutils 2.17.50.0.5.
  1. Update from binutils 2006 0927.
  2. Fix linker regressions of section address and section relative symbol
  with empty output section. PR 3223/3267.
  3. Fix "strings -T". PR 3257.
  4. Fix "objcopy --only-keep-debug". PR 3262.
  5. Add Intell iwmmxt2 support.
  6. Fix an x86 disassembler bug. PR 3100.
* Wed Sep 27 2006 schwab@suse.de
- Fix uninitialized memory.
* Mon Sep 25 2006 schwab@suse.de
- Update to binutils 2.17.50.0.4.
  1. Update from binutils 2006 0924.
  2. Speed up linker on .o files with debug info on linkonce sections.
  PR 3111.
  3. Added x86-64 PE support.
  4. Fix objcopy/strip on .o files with section groups. PR 3181.
  5. Fix "ld --hash-style=gnu" crash with gcc 3.4.6. PR 3197.
  6. Fix "strip --strip-debug" on .o files generated with
  "gcc -feliminate-dwarf2-dups". PR 3186.
  7. Fix "ld -r" on .o files generated with "gcc -feliminate-dwarf2-dups".
  PR 3249.
  8. Add --dynamic-list to linker to make global symbols dynamic.
  9. Fix magic number for EFI ia64. PR 3171.
  10. Remove PT_NULL segment for "ld -z relro". PR 3015.
  11. Make objcopy to perserve the file formats in archive elements.
  PR 3110.
  12. Optimize x86-64 assembler and fix disassembler for
  "add32 mov xx,$eax". PR 3235.
  13. Improve linker diagnostics. PR 3107.
  14. Fix "ld --sort-section name". PR 3009.
  15. Updated an x86 disassembler bug. PR 3000.
  16. Various updates for PPC, ARM, MIPS, SH, Xtensa.
  17. Added Score support.
* Thu Sep 21 2006 schwab@suse.de
- Add support for --dynamic-list.
* Wed Aug  9 2006 schwab@suse.de
- Enable -zrelro by default.
* Wed Jul 26 2006 schwab@suse.de
- Fix bad gp value [#190362].
* Mon Jul 17 2006 schwab@suse.de
- Update to binutils 2.17.50.0.3.
  1. Update from binutils 2006 0715.
  2. Add --hash-style to ELF linker with DT_GNU_HASH and SHT_GNU_HASH.
  3. Fix a visibility bug in ELF linker (PR 2884).
  4. Properly fix the i386 TLS linker bug (PR 2513).
  5. Add assembler and dissassembler support for Pentium Pro nops.
  6. Optimize x86 nops for Pentium Pro and above.
  7. Add -march=/-mtune= to x86 assembler.
  8. Fix an ELF linker with TLS common symbols.
  9. Improve program header allocation in ELF linker.
  10. Improve MIPS, M68K and ARM support.
  11. Fix an ELF linker crash when reporting alignment change (PR 2735).
  12. Remove unused ELF section symbols (PR 2723).
  13. Add --localize-hidden to objcopy.
  14. Add AMD SSE4a and ABM new instruction support.
  15. Properly handle illegal x86 instructions in group 11 (PR 2829).
  16. Add "-z max-page-size=" and "-z common-page-size=" to ELF linker.
  17. Fix objcopy for .tbss sections.
* Tue Jun 13 2006 schwab@suse.de
- Handle hash resizing during as-needed processing.
* Fri Jun  9 2006 schwab@suse.de
- Disable hash resizing.
* Sat Jun  3 2006 schwab@suse.de
- Fix DT_NEEDED search with --as-needed libraries.
- Fix bfd_hash_lookup.
* Fri May 26 2006 schwab@suse.de
- Update to binutils 2.17.50.0.2.
* Mon May 15 2006 schwab@suse.de
- Update to binutils 2.17.50.0.1.
* Mon May  8 2006 hare@suse.de
- Fix invalid exeception on S/390 when calling res_init()
  [#172700 - LTC23600]
* Fri May  5 2006 schwab@suse.de
- Fix huge link times [#167593].
* Tue Apr 11 2006 schwab@suse.de
- PR ld/2442: fix quadratic behaviour with many relocations [#157119].
- PR ld/2513: fix invalid TLS reloc merging [#162901].
* Mon Apr  3 2006 schwab@suse.de
- Add various bug fix backports collected by Alan Modra.  Fixes the
  following binutils bugs:
  * PR ld/2443
  * PR ld/2462
  * PR ld/2267
  * incompatibilities between REL{32,24,14}
  * ld -r on ppc64
  * -msecure-plt vs TLS
* Fri Mar 31 2006 schwab@suse.de
- Fix build race.
* Fri Mar 31 2006 matz@suse.de
- Also disallow linking non-PIC .o files into shared libraries on
  s390x.
* Fri Mar 31 2006 schwab@suse.de
- Fix bfd_find_nearest_line so that gcc -frepo works again.
* Wed Feb 15 2006 matz@suse.de
- Update -Bdirect and -zdynsort patches.
* Mon Feb  6 2006 matz@suse.de
- Adjust testsuite for s390 -march=z900 default.
- Disallow linking non-PIC .o files into shared libraries on s390.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jan 18 2006 matz@suse.de
- Add large model patch.
* Tue Jan 17 2006 schwab@suse.de
- Add patch to fix --gc-sections on ppc64.
- Fix side effect of --enable-targets=arm.
* Wed Jan 11 2006 schwab@suse.de
- Update to binutils 2.16.91.0.5.
* Tue Jan 10 2006 rguenther@suse.de
- Don't error out for testsuite failures on hppa.
* Tue Jan  3 2006 dmueller@suse.de
- Don't create empty rpath components when stripping
* Wed Dec  7 2005 schwab@suse.de
- Fix handling of SHF_LINK_ORDER links for objcopy.
* Wed Dec  7 2005 coolo@suse.de
- New -Bdirect patch.
* Fri Dec  2 2005 schwab@suse.de
- Add experimental -Bdirect patch.
* Thu Nov 24 2005 schwab@suse.de
- Fix aliasing warning.
* Sun Nov 13 2005 schwab@suse.de
- Update to binutils 2.16.91.0.4.
* Wed Nov  9 2005 schwab@suse.de
- Fixes from CVS:
  * Don't strip local absolute symbols from linker output.
  * Allow equating local symbols to undefined symbols.
* Fri Nov  4 2005 schwab@suse.de
- Fix more warnings.
* Wed Nov  2 2005 schwab@suse.de
- Fix warnings.
* Thu Oct 27 2005 aj@suse.de
- Spell fix.
* Wed Sep 28 2005 schwab@suse.de
- Add target i386-pe on ix86 and x86_64.
* Fri Sep 16 2005 schwab@suse.de
- Update to binutils 2.16.91.0.3.
* Thu Sep  1 2005 schwab@suse.de
- Fix objdump -adjust-vma on non-relocatable object [#114666].
* Wed Aug 10 2005 schwab@suse.de
- Replace last change by a simpler fix.
* Sat Aug  6 2005 schwab@suse.de
- Add hook for resetting GP after each relaxing pass.
* Fri Aug  5 2005 matz@suse.de
- Fix alpha again.
* Wed Aug  3 2005 schwab@suse.de
- Don't warn on overflow in the assembler if emitting a reloc on ppc
  [#100189].
- Fix handling of discarded linkonce sections [#84608].
* Tue Aug  2 2005 schwab@suse.de
- Avoid generating R_IA64_NONE.
* Tue Aug  2 2005 uli@suse.de
- disabled make check on ARM (one test fills up the hard disk;
  not a QEMU problem, happens on real hardware, too)
* Mon Jul 25 2005 schwab@suse.de
- Fix syntax error in libtool library files [#98185].
* Thu Jul 21 2005 schwab@suse.de
- Update to binutils 2.16.91.0.2.
* Thu Jun 23 2005 schwab@suse.de
- Update to binutils 2.16.91.0.1.
* Wed Jun 22 2005 schwab@suse.de
- Add patch to properly handle indirect symbols.
* Fri May 20 2005 schwab@suse.de
- Fix ld testsuite.
* Tue May 17 2005 schwab@suse.de
- Fix overflows in BFD library [#81821].
* Wed May 11 2005 schwab@suse.de
- Update to binutils 2.16.90.0.3.
- Build with -Wno-error in beta.
* Sat May  7 2005 schwab@suse.de
- Add patch to properly put unwind sections into section groups.
- Fix avr assembler.
* Sat May  7 2005 matz@suse.de
- added alpha cross target.
* Tue May  3 2005 jw@suse.de
- added target avr.
* Sun May  1 2005 schwab@suse.de
- Update to binutils 2.16.90.0.2.
* Thu Apr 28 2005 schwab@suse.de
- Update patch for last change.
* Mon Apr 25 2005 matz@suse.de
- Fix breakage on alpha
* Wed Apr 20 2005 bg@suse.de
- remove additional target hppa64
- remove obsolete hppa patch
- enable tests
* Sun Apr 17 2005 schwab@suse.de
- Accept empty symbol names.
- Fix bugs related to section groups.
* Wed Apr 13 2005 schwab@suse.de
- Fix mips assembler.
* Mon Apr 11 2005 schwab@suse.de
- Add patch to fix AS_NEEDED.
* Sun Apr 10 2005 schwab@suse.de
- Update to binutils 2.16.90.0.1.
* Wed Apr  6 2005 schwab@suse.de
- Cleanup neededforbuild.
- Fix compilation with gcc4.
* Wed Apr  6 2005 meissner@suse.de
- Added gettext-devel to neededforbuild.
* Tue Apr  5 2005 schwab@suse.de
- Revert last change (don't disable parallel build).
* Tue Apr  5 2005 meissner@suse.de
- Added gettext-devel to neededforbuild.
* Wed Mar 30 2005 schwab@suse.de
- Support AS_NEEDED in linker script.
* Fri Feb 18 2005 schwab@suse.de
- Update to binutils 2.15.94.0.2.2.
* Thu Feb  3 2005 schwab@suse.de
- Fix ld testsuite for gcc4.
* Sun Jan 30 2005 schwab@suse.de
- Add patch to properly handle protected functions for ia32 and x86_64.
* Thu Jan 20 2005 schwab@suse.de
- Fix last change.
* Wed Jan 19 2005 schwab@suse.de
- Handle biarch targets also for cross binutils.
* Sat Jan  8 2005 schwab@suse.de
- Update to binutils 2.15.94.0.2.
- Enable more targets.
* Tue Nov 23 2004 schwab@suse.de
- Update to binutils 2.15.94.0.1.
* Thu Oct 14 2004 schwab@suse.de
- Remove broken check.
* Wed Oct 13 2004 schwab@suse.de
- Fix ppc asm operand parsing.
* Fri Oct  8 2004 schwab@suse.de
- Update to binutils 2.15.92.0.2.
* Thu Sep  9 2004 schwab@suse.de
- Fix last change.
* Thu Sep  2 2004 schwab@suse.de
- Fix relro alignment.
* Sat Aug 21 2004 coolo@suse.de
- also build cross binutils for ppc64
* Fri Aug  6 2004 schwab@suse.de
- Fix crash in ld [#43550].
* Wed Aug  4 2004 schwab@suse.de
- Add patch for PR binutils/290.
* Sun Aug  1 2004 schwab@suse.de
- Make error about relocs against discarded sections non-fatal for now.
* Wed Jul 28 2004 schwab@suse.de
- Update to binutils 2.15.91.0.2.
* Fri Jun  4 2004 schwab@suse.de
- Update to binutils 2.15.91.0.1.
* Tue May  4 2004 coolo@suse.de
- created cross-*-binutils in the same directory reusing create-cross.sh
  as pre_checkin.sh
* Fri Apr 16 2004 aj@suse.de
- Fix some offset expressions.
* Thu Apr 15 2004 aj@suse.de
- Update to binutils 2.15.90.0.3.
* Wed Apr 14 2004 aj@suse.de
- Update to binutils 2.15.90.0.2.
* Fri Mar 26 2004 meissner@suse.de
- Added ppc64 patch to drop excess symbols in shared libraries.
* Tue Mar 23 2004 schwab@suse.de
- Fix --wrap on PPC64 [#34903].
* Tue Mar 16 2004 mludvig@suse.cz
- Added support for VIA PadLock.
- Merged obsolete fix-clflush.patch into opcode-i386.diff
* Fri Mar 12 2004 aj@suse.de
- Fix sysenter.
- Fix x86 clflush disassembly.
* Wed Mar 10 2004 schwab@suse.de
- Fix a possible race in the PLT.
* Mon Mar  8 2004 aj@suse.de
- Fix cfi testsuite on s390x.
* Mon Mar  8 2004 hare@suse.de
- Enable s390 biarch backend.
- Fix Invalid .insn from gas on s390.
* Mon Mar  8 2004 aj@suse.de
- Fix fde alignment.
* Sat Mar  6 2004 aj@suse.de
- Update to binutils-2.15.90.0.1.1 which incorporates the last two
  changes.
* Fri Mar  5 2004 schwab@suse.de
- Fix align handling.
* Thu Mar  4 2004 aj@suse.de
- Install as manpage.
* Thu Mar  4 2004 aj@suse.de
- Update to binutils-2.15.90.0.1.
* Fri Feb 27 2004 schwab@suse.de
- Support POSIX-compatible argument parsing in ar [#33775].
- Fix textrel patch.
* Thu Feb 26 2004 schwab@suse.de
- Fix spurious DT_TEXTREL.
* Wed Feb 25 2004 matz@suse.de
- Enable new dtags by default.
* Fri Feb 13 2004 hare@suse.de
- Fix memcmp bug in gas/dwarf2dbg.c
* Thu Feb 12 2004 bg@suse.de
- Workaround for ICE in elf32_hppa_relocate_section.
* Thu Jan 15 2004 aj@suse.de
- Fix common page size on ppc.
- Update to binutils 2.14.90.0.8.
* Mon Jan 12 2004 aj@suse.de
- Fix PPC64 TLS bug.
* Fri Dec 12 2003 schwab@suse.de
- Fix file list.
* Tue Dec  2 2003 schwab@suse.de
- Fix last change for ia64.
* Mon Nov 24 2003 aj@suse.de
- Fix handling of '/' in gas on x86 platforms.
* Thu Oct 30 2003 aj@suse.de
- Update to binutils 2.14.90.0.7:
  1. Update from binutils 2003 1029.
  2. Allow type changes for undefined symbols.
  3. Fix EH frame optimization.
  4. Fix the check for undefined versioned symbol with wildcard.
  5. Support generating code for Itanium.
  6. Detect and warn bad symbol index.
  7. Update IPF assemebler DV check.
* Fri Oct 17 2003 schwab@suse.de
- Update dv warning patch once more.
- Disable -Wunused during testsuite.
* Fri Oct 17 2003 schwab@suse.de
- Update dv warning patch.
* Wed Oct 15 2003 aj@suse.de
- Build as non-root user.
* Fri Oct  3 2003 kukuk@suse.de
- Remove tetex from neededforbuild
* Wed Oct  1 2003 schwab@suse.de
- Fix spurious dv conflict warning.
- Don't ignore testsuite failures on ia64.
* Fri Sep 26 2003 aj@suse.de
- Update to binutils-2.14.90.0.6.
* Fri Aug 29 2003 aj@suse.de
- Add patch to speed up linker.
* Tue Aug 19 2003 aj@suse.de
- disable unit-at-a-time for some tests so that they pass (otherwise
  some sections are reordered).
* Fri Aug  8 2003 schwab@suse.de
- Fix generation of efi-app binaries.
* Tue Jul 29 2003 meissner@suse.de
- Fix ppc64 bitmask detection (from current CVS).
* Fri Jul 25 2003 schwab@suse.de
- Readd workaround for missing DESTDIR support.
* Thu Jul 24 2003 aj@suse.de
- Update to binutils 2.14.90.0.5.
* Wed Jul 16 2003 mludvig@suse.cz
- Reverted Alan Modra's patch for .debug_line generation.
  http://sources.redhat.com/ml/binutils/2003-07/msg00294.html
* Fri Jul  4 2003 olh@suse.de
- update to binutils-2.14.90.0.4-cvs20030704.diff.bz2
* Wed Jul  2 2003 olh@suse.de
- add binutils-ppc64-mminimal-toc.patch
  - -disable-nls in cross-binutils, remove man and info to
  avoid file conflicts with multiple cross-binutils packages
* Wed Jul  2 2003 aj@suse.de
- Support z990 instructions.
* Mon Jun 30 2003 olh@suse.de
- add binutils_x86_64_bfd_c90.patch
* Fri Jun 27 2003 olh@suse.de
- update to binutils-2.14.90.0.4-cvs20030627.diff.bz2
  use DESTDIR
* Tue Jun 24 2003 coolo@suse.de
- ignore rpaths only for > 8.2
* Mon Jun 23 2003 coolo@suse.de
- removed %%ifarch mips
* Wed Jun 18 2003 aj@suse.de
- Fix CFI alignment bugs.
* Wed Jun 18 2003 olh@suse.de
- update to binutils-2.14.90.0.4-cvs20030618.diff.bz2
- provide an option to test a vanilla binutils release,
  provide an option to not apply patches that break the testsuite
* Tue Jun 17 2003 coolo@suse.de
- apply the cvs diff on all architectures and sort out the other
  patches
- use %%find_lang
- apply objcopy.c patch to add --only-keep-debug option to strip
  and objcopy
* Fri Jun 13 2003 olh@suse.de
- use binutils-2.14.90.0.4-cvs20030613.diff.bz2 on ppc/ppc64
  to remove the -mminimal-toc requirement on ppc64
* Thu Jun 12 2003 aj@suse.de
- Fix directory file list.
* Thu Jun  5 2003 ro@suse.de
- fix dangling ldscripts symlink for lib64 platforms
* Thu Jun  5 2003 aj@suse.de
- Fix typo in CFI calculation.
- Make .eh_frame section read-only.
- Add more CFI directives.
* Thu Jun  5 2003 coolo@suse.de
- integrating patch to ignore rpaths listed in a file specified
  by $SUSE_IGNORED_RPATHS (supposed to be set to /etc/ld.so.conf)
* Mon Jun  2 2003 aj@suse.de
- Fix addend relocation with CFI.
* Sat May 31 2003 aj@suse.de
- Handle GOT with more than 8191 entries corect on PowerPC.
- Fix dwarf2 CFI bugs.
* Fri May 30 2003 aj@suse.de
- Update to binutils 2.14.90.0.4.
- Improve cfi support.
* Wed May 21 2003 aj@suse.de
- Fix cfi build problems on ia64 and add latest revision of patch.
* Tue May 20 2003 aj@suse.de
- Fix elf visibility problem.
- Add cfi directives.
* Sat May 17 2003 aj@suse.de
- Update to binutils 2.14.90.0.2.
* Thu May 15 2003 aj@suse.de
- Allow testsuite to fail on sparc.
* Wed May 14 2003 schwab@suse.de
- Workaround lack of DESTDIR support.
- Make sure libbfd is installed before libopcodes.
* Wed May 14 2003 aj@suse.de
- Link libopcodes against libbfd.
- Fix package list.
* Mon May 12 2003 aj@suse.de
- Fix bugs and testsuite on s390.
* Wed May  7 2003 aj@suse.de
- Fix bugs in creation of large files.
* Tue May  6 2003 aj@suse.de
- Update to version 2.14.90.0.1.
* Mon Apr 28 2003 schwab@suse.de
- Update ia64 relaxation bug fix.
* Fri Apr 25 2003 aj@suse.de
- Fix ia64 relaxation bugs.
* Thu Apr 24 2003 olh@suse.de
- add binutils-2.13-ppc32-ld-symbol-version.patch
  add binutils-2.13-ppc32-fPIC.patch
    fail to link shared libs compiled without -fPIC
    run make check with -k after this change
* Thu Apr 24 2003 ro@suse.de
- fix install_info --delete call and move from preun to postun
* Tue Apr  8 2003 adrian@suse.de
- fix build for mips
* Sat Mar 22 2003 aj@suse.de
- Update to 2.13.0.90.20.
* Wed Mar 19 2003 aj@suse.de
- Do not depend on binutils installation.
* Wed Mar 19 2003 aj@suse.de
- Fix crash in ld with overly long command lines (#23743).
* Thu Feb 27 2003 aj@suse.de
- Package all libiberty include files.
* Wed Feb 19 2003 stepan@suse.de
- add create-cross.sh to easily create cross-binutils packages.
* Tue Feb 18 2003 aj@suse.de
- Run testsuite.
* Fri Feb 14 2003 aj@suse.de
- Fix symbol relocations with versioning.
* Mon Feb 10 2003 aj@suse.de
- Fix real.plt on s390.
* Fri Feb  7 2003 aj@suse.de
- Fix dwarf2 filenames.
* Thu Feb  6 2003 aj@suse.de
- Fix frame header sign extension bug (#23318)
- Fix library path for 64-bit platforms
- Fix x86-64 disassembler.
* Thu Feb  6 2003 stepan@suse.de
- Add alpha TLS patch
* Sat Feb  1 2003 aj@suse.de
- Add sparc TLS patch.
* Sat Jan 25 2003 aj@suse.de
- Update to binutils 2.13.90.0.18 which includes:
  * Fix some ia64 gas bugs.
  * Fix TLS bugs.
  * Fix ELF/ppc bugs.
* Tue Jan 14 2003 bg@suse.de
- add hppa relocation patch from "John David Anglin"
  <dave@hiauly1.hia.nrc.ca>
* Sat Dec 14 2002 adrian@suse.de
- add additional mips64 target on mips
- use mips patches which came with the tar ball on mips
- disable "make check" on mips for now
* Fri Dec  6 2002 schwab@suse.de
- Update to binutils 2.13.90.0.16.
* Wed Dec  4 2002 olh@suse.de
- add ppc64-binutils-ld-makecheck.diff, enable make check on ppc64
* Sat Nov 23 2002 olh@suse.de
- add ppc64-binutils-ld-no256mbsegments.diff
  revert the binutils change that moved text and data into separate
  256M address ranges, at least until the glibc dynamic loader
  can handle such binaries gracefully.
* Tue Nov  5 2002 bg@suse.de
- Enable hppa build
- Add support for hppa64
* Thu Oct 24 2002 aj@suse.de
- Fix allocation of orphaned sections to aviod problems with strip.
- Fix another problem on alpha with orphaned sections.
* Tue Oct 15 2002 aj@suse.de
- Install libiberty.h [Fixes #20941].
* Mon Oct 14 2002 aj@suse.de
- Update to binutils-2.13.90.0.10.
* Tue Oct  1 2002 aj@suse.de
- Update to binutils-2.13.90.0.5.
- Add tls support for x86-64.
- Fix tls support for i386.
* Mon Sep 16 2002 schwab@suse.de
- Enable use of brl for out of range branch fixup.
* Sun Sep  1 2002 aj@suse.de
- Fix LIB_PATH for x86_64.
* Fri Aug 30 2002 bk@suse.de
- enable s390 as additional target on s390x
- fix LIB_PATH for elf_s390 emulation to not use lib64 paths
- fix LIB_PATH for elf64_s390 to include /usr/local/lib64 and /lib64
- delete -fsigned-char for binutils on s390/s390x
* Tue Aug 27 2002 aj@suse.de
- Fix x86-64 gotpcrel generation.
- Add fix for bugs in gas on i386 where GOT references where
  miscompiled and fix problem with absolute section.
- Fix reference counting on various platforms.
- Fix counting of definitions in shared objects
* Fri Jul 19 2002 schwab@suse.de
- Update to binutils 2.12.90.0.15.
* Sat Jul 13 2002 schwab@suse.de
- Add fix for ia64 indirect call encoding bug.
* Thu Jul 11 2002 aj@suse.de
- Fix generation of nops for x86-64.
* Wed Jul 10 2002 aj@suse.de
- Fix -ffunction sections.
* Tue Jul  9 2002 olh@suse.de
- add patches for gas biarch support on ppc
  binutils-2.12.90.0.14-cvs.diff 20020709
  binutils_ppc_biarch_gas.diff
  binutils_ppc_biarch_gas_weaksym.diff
* Fri Jul  5 2002 kukuk@suse.de
- Use %%ix86 macro
* Wed Jul  3 2002 aj@suse.de
- Update to binutils 2.12.90.0.14.
- Remove patches that have been integrated.
* Tue Jul  2 2002 bk@suse.de
- add fixes for s390(x) - should make this version work for s390.
* Wed Jun 26 2002 aj@suse.de
- Do not discard empty sections (otherwise the kernel build will
  break).
* Thu Jun 20 2002 adrian@suse.de
- Update to binutils 2.12.90.0.12.
  * Update from binutils 2002 0618.
  * Fix an mips assembler bug.
- remove s390-testsuite.patch, it is inside 2.12.90.0.12 now
* Mon Jun 17 2002 aj@suse.de
- Abort with error message if shared libs are build without -fPIC
  on x86-64 (in cases where this can be detected).
- Remove ld -Y patch.
* Fri Jun 14 2002 olh@suse.de
- use _target_cpu in diff packagelist
* Wed Jun 12 2002 aj@suse.de
- Update to binutils 2.12.90.0.11.
- Better handle ld -Y with multilibs.
- Do not link 32-bit and 64-bit objects togethers when searching libs
  via ld.so.conf.
- Add x86-64 as target for i386.
* Fri May 31 2002 olh@suse.de
- update cvs patch to 20020531, obsolets ppc64_binutils.diff
  disable make check on ppc64
* Thu May 30 2002 olh@suse.de
- add binutils_x86_64_testsuite.diff, selective[1245] xfail on x86-64
* Wed May 29 2002 olh@suse.de
- add ppc64_binutils.diff, for libtool
  nm -B output, use D instead of ? for function descriptors
* Mon May 27 2002 olh@suse.de
- update cvs patch to 20020527
* Thu May 23 2002 olh@suse.de
- add cvs 20020523 diff for ppc/ppc64
  put readelf manpage in filelist
* Sun May 19 2002 olh@suse.de
- handle elf64 (powerpc64-suse-linux) on ppc32
* Fri May 17 2002 adrian@suse.de
- fix build for s390x and mips
  (added pic config file)
- do not ignore return value of "make check" on mips anymore
* Fri May 17 2002 schwab@suse.de
- Add gprof docs.
- Add message catalogues.
* Fri May 17 2002 uli@suse.de
- added gprof to file list
* Mon May 13 2002 schwab@suse.de
- Add PIC configuration for x86-64.
* Mon May 13 2002 olh@suse.de
- update to 2.12.90.0.7
* Sun May 12 2002 schwab@suse.de
- Install the PIC libiberty.a.
* Fri May 10 2002 meissner@suse.de
- x86-64 relocation conversion should not just convert to
  64bit relocations since we sometimes do have 32bit ones.
  (Patch from Andreas Schwab.)
* Tue Apr 23 2002 aj@suse.de
- Fix a bug with --eh-frame-hdr that occured on sparc.
* Mon Apr 22 2002 aj@suse.de
- Fix testsuite for alpha and s390.
- Fix --eh-frame-hdr.
- Update x86-64 assembler patch.
* Sat Apr 20 2002 schwab@suse.de
- Fix pcrel handling in x86-64 assembler.
* Wed Apr 17 2002 aj@suse.de
- Fix merging of s390 sections.
* Mon Apr 15 2002 aj@suse.de
- Fix PPC linker bug.
* Fri Apr 12 2002 aj@suse.de
- Update to binutils-2.12.90.0.4:
  * Contains x86-64 fix
  * Fixes S390 ld failure
  * Fixes for sparc
* Mon Apr  8 2002 aj@suse.de
- Add fix for pcrel relocations for x86-64.
* Tue Apr  2 2002 aj@suse.de
- Change platforms where testsuite is run.
* Mon Mar 25 2002 schwab@suse.de
- Update to binutils-2.12.90.0.3.
* Sun Mar 10 2002 schwab@suse.de
- Update to binutils-2.12.90.0.1.
- gprof now supported on MIPS.
* Thu Feb 28 2002 stepan@suse.de
- add data segment alignment patches.
* Mon Feb 25 2002 schwab@suse.de
- Add fix for elf64-ia64 linker scripts.
* Mon Feb 18 2002 schwab@suse.de
- Fix broken patch.
* Mon Feb 18 2002 aj@suse.de
- Update to binutils-2.11.93.0.2.
* Thu Feb 14 2002 aj@suse.de
- Fix bug in handling of version maps by ld.  This is needed for
  GCC 3.1.
* Mon Nov 26 2001 aj@suse.de
- gprof is not supported on MIPS, don't try to package it.
* Thu Nov 15 2001 adrian@suse.de
- ignore known problem on mips in testsuite
- disable combreloc patch for mips
* Wed Nov 14 2001 ro@suse.de
- added include file symcat.h to filelist
* Mon Nov 12 2001 aj@suse.de
- Update to binutils-2.11.92.0.10.
* Sun Sep 30 2001 schwab@suse.de
- Update to  binutils 2.11.90.0.31.
- Add support for @iplt and .data16 on ia64.
* Mon Sep  3 2001 aj@suse.de
- Fix relative relocations on Alpha.
* Thu Aug 30 2001 aj@suse.de
- Update to binutils 2.11.90.0.29.  It includes support for 64-bit
  PowerPC.
* Mon Aug 27 2001 aj@suse.de
- Update to current CVS version and include patch to always enable
  sorting of relocations.  Together with the new glibc this reduces
  relocation processing at program startup significantly.
* Wed Aug 22 2001 aj@suse.de
- Use AltiVec/PPC patch.
- Revert objdump patch that causes sparc kernel build failure.
- Add missing s390 jump instructions.
- Fix bug with unaligned accesses in the sparc assembler.
* Fri Aug 17 2001 egger@suse.de
- Added patch for missing AltiVec/PPC opcodes.
* Thu Aug 16 2001 aj@suse.de
- Update to 2.11.90.0.27, fix s390 relocation generation.
* Tue Jul 17 2001 aj@suse.de
- Update to binutils 2.11.90.0.24.
* Wed Jul 11 2001 aj@suse.de
- Update to binutils 2.11.90.0.23.
* Wed Jun 13 2001 aj@suse.de
- Run testsuite on s390.
* Tue Jun 12 2001 aj@suse.de
- Update to binutils 2.11.90.0.15.
* Mon May 14 2001 aj@suse.de
- Update to binutils 2.11.90.0.8.
* Mon May  7 2001 aj@suse.de
- Update to latest version.
* Thu Mar 29 2001 aj@suse.de
- Fix a relaxation bug on ia32 that occurs while building GCC.
* Tue Mar 27 2001 aj@suse.de
- Test for alpha instead of axp.
* Mon Mar 26 2001 aj@suse.de
- Add patch for S390 to fix relocs.
* Mon Mar 26 2001 aj@suse.de
- The testsuite is broken on axp, disable it.
* Thu Mar  8 2001 aj@suse.de
- Use separate build directory, don't run testsuite on sparc.
* Mon Mar  5 2001 aj@suse.de
- Update to 2.10.91.0.4.
* Thu Feb 22 2001 aj@suse.de
- Run the testsuite on some platforms.
* Tue Feb 20 2001 aj@suse.de
- Add sparc fix for weak symbols.
* Mon Feb 19 2001 aj@suse.de
- Update to 2.10.91.0.2.
* Thu Nov 16 2000 aj@suse.de
- Added an alpha patch to fix glibc problems.
* Mon Oct 23 2000 aj@suse.de
- Update to 2.10.0.33.
- Remove PPC patch since it's solved better in .33.
* Sun Oct 15 2000 kukuk@suse.de
- Update to binutils 2.10.0.31
- Port s390 patches
- Add PPC patch to fix glibc 2.2 problems
* Thu Sep 14 2000 kukuk@suse.de
- Use macros in spec file
* Tue Aug 29 2000 aj@suse.de
- New version 2.10.0.24 with additional s390 patches.
* Sun Apr 16 2000 ro@suse.de
- added alpha3.dif to fix another problem with compaq compilers
* Sat Mar 18 2000 aj@suse.de
- Fix problems with Compaq compiler, see:
  http://sourceware.cygnus.com/ml/binutils/2000-03/msg00226.html
  http://sourceware.cygnus.com/ml/binutils/2000-03/msg00160.html
* Mon Mar 13 2000 aj@suse.de
- Added readelf to file list.
* Mon Feb 28 2000 ro@suse.de
- fix HOST macro
- added alpha fix from Andrea
* Thu Jan 20 2000 aj@suse.de
- New version 2.9.5.0.24.
* Thu Dec  9 1999 ro@suse.de
- leave targets for now
* Wed Dec  8 1999 kasal@suse.de
- added buildroot
  (it required a patch to target ld/Makefile.am, target install-data-local)
* Tue Nov 23 1999 kasal@suse.de
- backported sparc patch from cvs version of binutils
- added note that geo@suse.cz can make NLMs
* Tue Nov 16 1999 kukuk@suse.de
- Remove broken Sparc as patch, add bfd patch for sparc32
* Wed Nov 10 1999 kukuk@suse.de
- spec file cleanup, add support for Sparc
- Remove dependency for bin86, not longer necessary
* Tue Nov  9 1999 uli@suse.de
- added PPC-specific files to %%files section
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Tue Aug 24 1999 uli@suse.de
- fixed Makefile.Linux for PPC
* Fri May 28 1999 ro@suse.de
- update to .25
* Thu Apr  8 1999 ro@suse.de
- update to .23
* Mon Mar 29 1999 ro@suse.de
- remove hacks and install libiberty.a in /usr/lib
* Sun Mar 14 1999 ro@suse.de
- libtool tries to be smart dropping the link -liberty
  try to be smarter: changed "-liberty" to "../libiberty/libiberty.a"
* Fri Mar  5 1999 ro@suse.de
- update to 2.9.1.0.22b FOR NOW AXP ONLY
- libnaming changed
* Fri Feb 19 1999 ro@suse.de
- update to 2.9.1.0.20
* Mon Jan 11 1999 ro@suse.de
- adapted specfile to build on alpha, too
- added ansidecl.h to filelist for glibc
* Mon Nov  2 1998 ro@suse.de
- update to 2.9.1.0.15
* Fri Sep 11 1998 ro@suse.de
- switch detection of GLIBC to automake
* Tue Jul  7 1998 ro@suse.de
- pack files depending on used libc / compile a.out for libc5
* Wed May 20 1998 bs@suse.de
- took c++filt off from file list (is included in egcs)
* Wed May  6 1998 florian@suse.de
- update to binutils 2.9.1.0.4
* Tue Jul 29 1997 florian@suse.de
- the a.out-assembler was not installed correctly by "make install"
* Wed Jun 25 1997 florian@suse.de
- add bug-fixes from gnu.utils.bugs
* Sun Jun  8 1997 florian@suse.de
- always remove /usr/bin/encaps
* Sun Jun  8 1997 florian@suse.de
- update to version 2.8.1 with fixes by H.J. Lu
* Thu Jan  2 1997 florian@suse.de
- Update auf Version 2.7.0.3. Sollte jetzt als normales binutils-Paket
  installiert sein. 2.6.* hoechstens unter unsorted...
